#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_0 = {}

data_1 = {
    "Category:1960s in Papua New Guinean sport": "x",
    "Category:1962 in Papua New Guinean sport": "x",
    "Category:1969 in Papua New Guinean sport": "x",
    "Category:1970s in Papua New Guinean sport": "x",
    "Category:1975 in Papua New Guinean sport": "x",
    "Category:1976 in Papua New Guinean sport": "x",
    "Category:1980s in Papua New Guinean sport": "x",
    "Category:1982 in Papua New Guinean sport": "x",
    "Category:1983 in Papua New Guinean sport": "x",
    "Category:1984 in Papua New Guinean sport": "x",
    "Category:1985 in Papua New Guinean sport": "x",
    "Category:1986 in Papua New Guinean sport": "x",
    "Category:1988 in Papua New Guinean rugby league": "x",
    "Category:1988 in Papua New Guinean sport": "x",
    "Category:1989 in Papua New Guinean sport": "x",
    "Category:1990 in Papua New Guinean rugby league": "x",
    "Category:1990 in Papua New Guinean sport": "x",
    "Category:1990s in Papua New Guinean sport": "x",
    "Category:1990s in Papua New Guinean television": "x",
    "Category:1990s Papua New Guinean television series": "x",
    "Category:1991 in Papua New Guinean rugby league": "x",
    "Category:1991 in Papua New Guinean sport": "x",
    "Category:1992 in Papua New Guinean rugby league": "x",
    "Category:1992 in Papua New Guinean sport": "x",
    "Category:1994 in Papua New Guinean rugby league": "x",
    "Category:1994 in Papua New Guinean sport": "x",
    "Category:1996 in Papua New Guinean rugby league": "x",
    "Category:1996 in Papua New Guinean sport": "x",
    "Category:1997 in Papua New Guinean sport": "x",
    "Category:2000 in Papua New Guinean sport": "x",
    "Category:2000s in Papua New Guinean sport": "x",
    "Category:2001 in Papua New Guinean rugby league": "x",
    "Category:2001 in Papua New Guinean soccer": "x",
    "Category:2001 in Papua New Guinean sport": "x",
    "Category:2003 in Papua New Guinean sport": "x",
    "Category:2004 in Papua New Guinean sport": "x",
    "Category:2005 in Papua New Guinean sport": "x",
    "Category:2006 in Papua New Guinean sport": "x",
    "Category:2007 in Papua New Guinean sport": "x",
    "Category:2008 in Papua New Guinean sport": "x",
    "Category:2009 in Papua New Guinean sport": "x",
    "Category:2010 in Papua New Guinean sport": "x",
    "Category:2010s in Papua New Guinean sport": "x",
    "Category:2011 in Papua New Guinean sport": "x",
    "Category:2011–2012 Papua New Guinean constitutional crisis": "x",
    "Category:2012 in Papua New Guinean sport": "x",
    "Category:2013 in Papua New Guinean sport": "x",
    "Category:2014 in Papua New Guinean sport": "x",
    "Category:2015 in Papua New Guinean sport": "x",
    "Category:2016 in Papua New Guinean cricket": "x",
    "Category:2016 in Papua New Guinean sport": "x",
    "Category:2017 in Papua New Guinean cricket": "x",
    "Category:2017 in Papua New Guinean sport": "x",
    "Category:2018 in Papua New Guinean sport": "x",
    "Category:2019 in Papua New Guinean cricket": "x",
    "Category:2019 in Papua New Guinean sport": "x",
    "Category:2020 in Papua New Guinean sport": "x",
    "Category:2020s in Papua New Guinean cricket": "x",
    "Category:2020s in Papua New Guinean sport": "x",
    "Category:2021 in Papua New Guinean cricket": "x",
    "Category:2021 in Papua New Guinean sport": "x",
    "Category:2022 in Papua New Guinean cricket": "x",
    "Category:2022 in Papua New Guinean sport": "x",
    "Category:2023 in Papua New Guinean cricket": "x",
    "Category:2023 in Papua New Guinean sport": "x",
    "Category:2024 in Papua New Guinean cricket": "x",
    "Category:2024 in Papua New Guinean sport": "x",
    "Category:2025 in Papua New Guinean sport": "x",
    "Category:20th century in Papua New Guinean television": "x",
    "Category:20th-century Papua New Guinean businesspeople": "x",
    "Category:20th-century Papua New Guinean painters": "x",
    "Category:20th-century Papua New Guinean people": "x",
    "Category:20th-century Papua New Guinean politicians": "x",
    "Category:20th-century Papua New Guinean sportsmen": "x",
    "Category:20th-century Papua New Guinean sportspeople": "x",
    "Category:20th-century Papua New Guinean sportswomen": "x",
    "Category:20th-century Papua New Guinean television series": "x",
    "Category:21st-century Papua New Guinean people": "x",
    "Category:21st-century Papua New Guinean politicians": "x",
    "Category:21st-century Papua New Guinean sportsmen": "x",
    "Category:21st-century Papua New Guinean sportspeople": "x",
    "Category:21st-century Papua New Guinean sportswomen": "x",
    "Category:Albums by Papua New Guinean artists": "x",
    "Category:Albums by Papua New Guinean artists by genre": "x",
    "Category:Assassinated Papua New Guinean politicians": "x",
    "Category:Australian people of Papua New Guinean descent": "x",
    "Category:British people of Papua New Guinean descent": "x",
    "Category:Fijian people of Papua New Guinean descent": "x",
    "Category:Hip-hop albums by Papua New Guinean artists": "x",
    "Category:Japanese people of Papua New Guinean descent": "x",
    "Category:Lists of Papua New Guinean ambassadors": "x",
    "Category:Lists of Papua New Guinean cricketers": "x",
    "Category:Lists of Papua New Guinean people": "x",
    "Category:Lists of Papua New Guinean sportspeople": "x",
    "Category:New Zealand people of Papua New Guinean descent": "x",
    "Category:Papua New Guinean academics": "x",
    "Category:Papua New Guinean accountants": "x",
    "Category:Papua New Guinean activists": "x",
    "Category:Papua New Guinean actor-politicians": "x",
    "Category:Papua New Guinean actors": "x",
    "Category:Papua New Guinean airport stubs": "x",
    "Category:Papua New Guinean Anglicans": "x",
    "Category:Papua New Guinean anti-corruption activists": "x",
    "Category:Papua New Guinean anti-war activists": "x",
    "Category:Papua New Guinean archaeologists": "x",
    "Category:Papua New Guinean artists": "x",
    "Category:Papua New Guinean athletes": "x",
    "Category:Papua New Guinean aviators": "x",
    "Category:Papua New Guinean award winners": "x",
    "Category:Papua New Guinean awards": "x",
    "Category:Papua New Guinean badminton players": "x",
    "Category:Papua New Guinean bankers": "x",
    "Category:Papua New Guinean basketball players": "x",
    "Category:Papua New Guinean beatified people": "x",
    "Category:Papua New Guinean biologists": "x",
    "Category:Papua New Guinean bishops": "x",
    "Category:Papua New Guinean bowling players": "x",
    "Category:Papua New Guinean bowls players": "x",
    "Category:Papua New Guinean boxers": "x",
    "Category:Papua New Guinean broadcasters": "x",
    "Category:Papua New Guinean building and structure stubs": "x",
    "Category:Papua New Guinean businesspeople": "x",
    "Category:Papua New Guinean businesswomen": "x",
    "Category:Papua New Guinean cardinals": "x",
    "Category:Papua New Guinean chess players": "x",
    "Category:Papua New Guinean Christian missionaries": "x",
    "Category:Papua New Guinean Christians": "x",
    "Category:Papua New Guinean civil servants": "x",
    "Category:Papua New Guinean clergy": "x",
    "Category:Papua New Guinean climate activists": "x",
    "Category:Papua New Guinean Commanders of the Order of the British Empire": "x",
    "Category:Papua New Guinean competitors by sports event": "x",
    "Category:Papua New Guinean cricket captains": "x",
    "Category:Papua New Guinean cricket coaches": "x",
    "Category:Papua New Guinean cricket people": "x",
    "Category:Papua New Guinean cricket tours abroad": "x",
    "Category:Papua New Guinean cricket tours of Australia": "x",
    "Category:Papua New Guinean cricket tours of Hong Kong": "x",
    "Category:Papua New Guinean cricket tours of the United Arab Emirates": "x",
    "Category:Papua New Guinean cricket umpires": "x",
    "Category:Papua New Guinean cricketers": "x",
    "Category:Papua New Guinean criminals": "x",
    "Category:Papua New Guinean cuisine": "x",
    "Category:Papua New Guinean curators": "x",
    "Category:Papua New Guinean dancers": "x",
    "Category:Papua New Guinean decathletes": "x",
    "Category:Papua New Guinean deities": "x",
    "Category:Papua New Guinean designers": "x",
    "Category:Papua New Guinean diaspora": "x",
    "Category:Papua New Guinean diplomats": "x",
    "Category:Papua New Guinean dramatists and playwrights": "x",
    "Category:Papua New Guinean economists": "x",
    "Category:Papua New Guinean editors": "x",
    "Category:Papua New Guinean educators": "x",
    "Category:Papua New Guinean emigrants": "x",
    "Category:Papua New Guinean emigrants to Australia": "x",
    "Category:Papua New Guinean emigrants to Canada": "x",
    "Category:Papua New Guinean emigrants to Japan": "x",
    "Category:Papua New Guinean emigrants to New Zealand": "x",
    "Category:Papua New Guinean environmentalists": "x",
    "Category:Papua New Guinean evangelicals": "x",
    "Category:Papua New Guinean expatriate judges": "x",
    "Category:Papua New Guinean expatriate men's soccer players": "x",
    "Category:Papua New Guinean expatriate rugby league players": "x",
    "Category:Papua New Guinean expatriate rugby league players in Australia": "x",
    "Category:Papua New Guinean expatriate rugby league players in England": "x",
    "Category:Papua New Guinean expatriate rugby union players": "x",
    "Category:Papua New Guinean expatriate soccer players": "x",
    "Category:Papua New Guinean expatriate sportspeople": "x",
    "Category:Papua New Guinean expatriate sportspeople by country of residence": "x",
    "Category:Papua New Guinean expatriate sportspeople in Australia": "x",
    "Category:Papua New Guinean expatriate sportspeople in England": "x",
    "Category:Papua New Guinean expatriate sportspeople in Finland": "x",
    "Category:Papua New Guinean expatriate sportspeople in France": "x",
    "Category:Papua New Guinean expatriate sportspeople in Malaysia": "x",
    "Category:Papua New Guinean expatriate sportspeople in New Zealand": "x",
    "Category:Papua New Guinean expatriate sportspeople in the Netherlands": "x",
    "Category:Papua New Guinean expatriate sportspeople in the Philippines": "x",
    "Category:Papua New Guinean expatriate sportspeople in the Solomon Islands": "x",
    "Category:Papua New Guinean expatriate sportspeople in the United Kingdom": "x",
    "Category:Papua New Guinean expatriate sportspeople in the United States": "x",
    "Category:Papua New Guinean expatriate sportspeople in Wales": "x",
    "Category:Papua New Guinean expatriate women's soccer players": "x",
    "Category:Papua New Guinean expatriates": "x",
    "Category:Papua New Guinean expatriates in Australia": "x",
    "Category:Papua New Guinean expatriates in Belgium": "x",
    "Category:Papua New Guinean expatriates in England": "x",
    "Category:Papua New Guinean expatriates in Fiji": "x",
    "Category:Papua New Guinean expatriates in Finland": "x",
    "Category:Papua New Guinean expatriates in France": "x",
    "Category:Papua New Guinean expatriates in New Zealand": "x",
    "Category:Papua New Guinean expatriates in the Netherlands": "x",
    "Category:Papua New Guinean expatriates in the Solomon Islands": "x",
    "Category:Papua New Guinean expatriates in the United Kingdom": "x",
    "Category:Papua New Guinean expatriates in the United States": "x",
    "Category:Papua New Guinean expatriates in Wales": "x",
    "Category:Papua New Guinean farmers": "x",
    "Category:Papua New Guinean fashion designers": "x",
    "Category:Papua New Guinean female bowls players": "x",
    "Category:Papua New Guinean female freestyle swimmers": "x",
    "Category:Papua New Guinean female martial artists": "x",
    "Category:Papua New Guinean female rugby league players": "x",
    "Category:Papua New Guinean female rugby union players": "x",
    "Category:Papua New Guinean female sailors (sport)": "x",
    "Category:Papua New Guinean female swimmers": "x",
    "Category:Papua New Guinean female taekwondo practitioners": "x",
    "Category:Papua New Guinean female tennis players": "x",
    "Category:Papua New Guinean female weightlifters": "x",
    "Category:Papua New Guinean football biography stubs": "x",
    "Category:Papua New Guinean football managers": "x",
    "Category:Papua New Guinean gospel singers": "x",
    "Category:Papua New Guinean heptathletes": "x",
    "Category:Papua New Guinean high jumpers": "x",
    "Category:Papua New Guinean historians": "x",
    "Category:Papua New Guinean hurdlers": "x",
    "Category:Papua New Guinean javelin throwers": "x",
    "Category:Papua New Guinean journalists": "x",
    "Category:Papua New Guinean judges": "x",
    "Category:Papua New Guinean judges on the courts of Fiji": "x",
    "Category:Papua New Guinean judoka": "x",
    "Category:Papua New Guinean knights": "x",
    "Category:Papua New Guinean Knights Bachelor": "x",
    "Category:Papua New Guinean Knights Commander of the Order of St Michael and St George": "x",
    "Category:Papua New Guinean Knights Commander of the Order of the British Empire": "x",
    "Category:Papua New Guinean lawyers": "x",
    "Category:Papua New Guinean librarians": "x",
    "Category:Papua New Guinean literature": "x",
    "Category:Papua New Guinean long jumpers": "x",
    "Category:Papua New Guinean long-distance runners": "x",
    "Category:Papua New Guinean male bowls players": "x",
    "Category:Papua New Guinean male boxers": "x",
    "Category:Papua New Guinean male judoka": "x",
    "Category:Papua New Guinean male martial artists": "x",
    "Category:Papua New Guinean male sailors (sport)": "x",
    "Category:Papua New Guinean male sport shooters": "x",
    "Category:Papua New Guinean male swimmers": "x",
    "Category:Papua New Guinean male taekwondo practitioners": "x",
    "Category:Papua New Guinean male weightlifters": "x",
    "Category:Papua New Guinean marathon runners": "x",
    "Category:Papua New Guinean martial artists": "x",
    "Category:Papua New Guinean mass media people": "x",
    "Category:Papua New Guinean media personalities": "x",
    "Category:Papua New Guinean members of the Privy Council of the United Kingdom": "x",
    "Category:Papua New Guinean men": "x",
    "Category:Papua New Guinean men athletes": "x",
    "Category:Papua New Guinean men hurdlers": "x",
    "Category:Papua New Guinean men javelin throwers": "x",
    "Category:Papua New Guinean men long-distance runners": "x",
    "Category:Papua New Guinean men marathon runners": "x",
    "Category:Papua New Guinean men middle-distance runners": "x",
    "Category:Papua New Guinean men sprinters": "x",
    "Category:Papua New Guinean men's basketball players": "x",
    "Category:Papua New Guinean men's soccer players": "x",
    "Category:Papua New Guinean middle-distance runners": "x",
    "Category:Papua New Guinean military personnel": "x",
    "Category:Papua New Guinean miners": "x",
    "Category:Papua New Guinean missionaries": "x",
    "Category:Papua New Guinean murder victims": "x",
    "Category:Papua New Guinean murderers": "x",
    "Category:Papua New Guinean musical instruments": "x",
    "Category:Papua New Guinean musicians": "x",
    "Category:Papua New Guinean mythology": "x",
    "Category:Papua New Guinean netball players": "x",
    "Category:Papua New Guinean newspaper editors": "x",
    "Category:Papua New Guinean novelists": "x",
    "Category:Papua New Guinean officials of the United Nations": "x",
    "Category:Papua New Guinean One Day International cricket umpires": "x",
    "Category:Papua New Guinean painters": "x",
    "Category:Papua New Guinean para-badminton players": "x",
    "Category:Papua New Guinean people": "x",
    "Category:Papua New Guinean people by descent": "x",
    "Category:Papua New Guinean people by occupation": "x",
    "Category:Papua New Guinean people by political orientation": "x",
    "Category:Papua New Guinean people by province": "x",
    "Category:Papua New Guinean people by region": "x",
    "Category:Papua New Guinean people by religion": "x",
    "Category:Papua New Guinean people in sports": "x",
    "Category:Papua New Guinean people of Asian descent": "x",
    "Category:Papua New Guinean people of Australian descent": "x",
    "Category:Papua New Guinean people of Austrian descent": "x",
    "Category:Papua New Guinean people of British descent": "x",
    "Category:Papua New Guinean people of Chinese descent": "x",
    "Category:Papua New Guinean people of Cypriot descent": "x",
    "Category:Papua New Guinean people of English descent": "x",
    "Category:Papua New Guinean people of European descent": "x",
    "Category:Papua New Guinean people of Filipino descent": "x",
    "Category:Papua New Guinean people of German descent": "x",
    "Category:Papua New Guinean people of Greek Cypriot descent": "x",
    "Category:Papua New Guinean people of Greek descent": "x",
    "Category:Papua New Guinean people of Irish descent": "x",
    "Category:Papua New Guinean people of Japanese descent": "x",
    "Category:Papua New Guinean people of Lithuanian descent": "x",
    "Category:Papua New Guinean people of Malaysian descent": "x",
    "Category:Papua New Guinean people of Oceanian descent": "x",
    "Category:Papua New Guinean people of Sri Lankan descent": "x",
    "Category:Papua New Guinean people of Tongan descent": "x",
    "Category:Papua New Guinean people of Welsh descent": "x",
    "Category:Papua New Guinean people stubs": "x",
    "Category:Papua New Guinean people with disabilities": "x",
    "Category:Papua New Guinean philosophers": "x",
    "Category:Papua New Guinean physicians": "x",
    "Category:Papua New Guinean players of Australian rules football": "x",
    "Category:Papua New Guinean poets": "x",
    "Category:Papua New Guinean police officers": "x",
    "Category:Papua New Guinean political people": "x",
    "Category:Papua New Guinean politicians": "x",
    "Category:Papua New Guinean politicians by party": "x",
    "Category:Papua New Guinean politicians of Chinese descent": "x",
    "Category:Papua New Guinean prisoners and detainees": "x",
    "Category:Papua New Guinean prisoners sentenced to death": "x",
    "Category:Papua New Guinean Protestant missionaries": "x",
    "Category:Papua New Guinean Protestants": "x",
    "Category:Papua New Guinean radio people": "x",
    "Category:Papua New Guinean radio personalities": "x",
    "Category:Papua New Guinean recipients of British honours": "x",
    "Category:Papua New Guinean recipients of British titles": "x",
    "Category:Papua New Guinean recipients of the British Empire Medal": "x",
    "Category:Papua New Guinean records": "x",
    "Category:Papua New Guinean referees and umpires": "x",
    "Category:Papua New Guinean religious leaders": "x",
    "Category:Papua New Guinean Roman Catholic archbishops": "x",
    "Category:Papua New Guinean Roman Catholic bishops": "x",
    "Category:Papua New Guinean Roman Catholic priests": "x",
    "Category:Papua New Guinean Roman Catholics": "x",
    "Category:Papua New Guinean rugby league administrators": "x",
    "Category:Papua New Guinean rugby league coaches": "x",
    "Category:Papua New Guinean rugby league players": "x",
    "Category:Papua New Guinean rugby league players by province": "x",
    "Category:Papua New Guinean rugby league seasons": "x",
    "Category:Papua New Guinean rugby union players": "x",
    "Category:Papua New Guinean runners": "x",
    "Category:Papua New Guinean sailors (sport)": "x",
    "Category:Papua New Guinean schoolteachers": "x",
    "Category:Papua New Guinean scientists": "x",
    "Category:Papua New Guinean Seventh-day Adventists": "x",
    "Category:Papua New Guinean shot putters": "x",
    "Category:Papua New Guinean singers": "x",
    "Category:Papua New Guinean soccer logos": "x",
    "Category:Papua New Guinean soccer players": "x",
    "Category:Papua New Guinean soccer referees": "x",
    "Category:Papua New Guinean social democrats": "x",
    "Category:Papua New Guinean social workers": "x",
    "Category:Papua New Guinean sport by decade": "x",
    "Category:Papua New Guinean sport by year": "x",
    "Category:Papua New Guinean sport shooters": "x",
    "Category:Papua New Guinean sport stubs": "x",
    "Category:Papua New Guinean sports coaches": "x",
    "Category:Papua New Guinean sportsmen": "x",
    "Category:Papua New Guinean sportspeople": "x",
    "Category:Papua New Guinean sportspeople by province": "x",
    "Category:Papua New Guinean sportspeople by sport": "x",
    "Category:Papua New Guinean sportspeople stubs": "x",
    "Category:Papua New Guinean sportsperson-politicians": "x",
    "Category:Papua New Guinean sportswomen": "x",
    "Category:Papua New Guinean sprinters": "x",
    "Category:Papua New Guinean steeplechase runners": "x",
    "Category:Papua New Guinean swimmers": "x",
    "Category:Papua New Guinean taekwondo practitioners": "x",
    "Category:Papua New Guinean television series": "x",
    "Category:Papua New Guinean television series by century": "x",
    "Category:Papua New Guinean television series by decade": "x",
    "Category:Papua New Guinean television shows": "x",
    "Category:Papua New Guinean tennis players": "x",
    "Category:Papua New Guinean theatre people": "x",
    "Category:Papua New Guinean trade unionists": "x",
    "Category:Papua New Guinean triple jumpers": "x",
    "Category:Papua New Guinean Twenty20 International cricket umpires": "x",
    "Category:Papua New Guinean victims of crime": "x",
    "Category:Papua New Guinean weightlifters": "x",
    "Category:Papua New Guinean Wikipedians": "x",
    "Category:Papua New Guinean women": "x",
    "Category:Papua New Guinean women academics": "x",
    "Category:Papua New Guinean women activists": "x",
    "Category:Papua New Guinean women artists": "x",
    "Category:Papua New Guinean women athletes": "x",
    "Category:Papua New Guinean women by occupation": "x",
    "Category:Papua New Guinean women civil servants": "x",
    "Category:Papua New Guinean women cricketers": "x",
    "Category:Papua New Guinean women diplomats": "x",
    "Category:Papua New Guinean women environmentalists": "x",
    "Category:Papua New Guinean women fashion designers": "x",
    "Category:Papua New Guinean women hurdlers": "x",
    "Category:Papua New Guinean women in politics": "x",
    "Category:Papua New Guinean women javelin throwers": "x",
    "Category:Papua New Guinean women lawyers": "x",
    "Category:Papua New Guinean women long-distance runners": "x",
    "Category:Papua New Guinean women middle-distance runners": "x",
    "Category:Papua New Guinean women runners": "x",
    "Category:Papua New Guinean women scientists": "x",
    "Category:Papua New Guinean women shot putters": "x",
    "Category:Papua New Guinean women sprinters": "x",
    "Category:Papua New Guinean women writers": "x",
    "Category:Papua New Guinean women's basketball players": "x",
    "Category:Papua New Guinean women's rights activists": "x",
    "Category:Papua New Guinean women's soccer players": "x",
    "Category:Papua New Guinean writers": "x",
    "Category:People of Papua New Guinean descent": "x",
    "Category:Reggae albums by Papua New Guinean artists": "x",
    "Category:Seasons in Papua New Guinean soccer": "x",
    "Category:Seasons in Papua New Guinean sport": "x",
    "Category:Surnames of Papua New Guinean origin": "x",
    "Category:Works by Papua New Guinean people": "x",
}
to_test = [
    ("test_papua_new_guinean_0", data_0),
    ("test_papua_new_guinean_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.skip2
def test_papua_new_guinean_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""Integration tests for format_multi_data  """

import pytest

from ArWikiCats.translations_formats import FormatData, MultiDataFormatterBase

nationality_data = {
    "Afghan": {"male": "أفغاني", "males": "أفغان"},
    "yemeni": {"male": "يمني", "males": "يمنيون"},
    "british": {"male": "بريطاني", "males": "بريطانيون"},
    "american": {"male": "أمريكي", "males": "أمريكيون"},
    "egyptian": {"male": "مصري", "males": "مصريون"},
    "Algerian": {"male": "جزائري", "males": "جزائريون"},
    "Moroccan": {"male": "مغربي", "males": "مغاربة"},
}

formatted_data = {
    "{nat1_en} {nat2_en}": "{nat1_men} {nat2_man}",
    "{nat1_en} people": "{nat1_men}",
    "{nat1_en} people of {nat2_en} descent": "{nat1_men} من أصل {nat2_man}",
    "{nat1_en} people of {nat2_en} jewish descent": "{nat1_men} من أصل يهودي {nat2_man}",
}

nationality_data_men = {x: v["males"] for x, v in nationality_data.items()}
nationality_data_man = {x: v["male"] for x, v in nationality_data.items()}


@pytest.fixture
def multi_bot() -> MultiDataFormatterBase:
    # Country bot (FormatData)
    country_bot = FormatData(
        formatted_data=formatted_data,
        data_list=nationality_data_men,
        key_placeholder="{nat1_en}",
        value_placeholder="{nat1_men}",
    )

    other_bot = FormatData(
        {},  # to use from search_all
        nationality_data_man,
        key_placeholder="{nat2_en}",
        value_placeholder="{nat2_man}",
    )

    return MultiDataFormatterBase(
        country_bot=country_bot,
        other_bot=other_bot,
    )


test_match_key_data = {
    "Afghan people": "أفغان",
    "Afghan people of American descent": "أفغان من أصل أمريكي",
    "American people of Afghan descent": "أمريكيون من أصل أفغاني",
    "Algerian people of Moroccan Jewish descent": "جزائريون من أصل يهودي مغربي",
}


@pytest.mark.parametrize("category, expected", test_match_key_data.items(), ids=test_match_key_data.keys())
@pytest.mark.fast
def test_standers(multi_bot: MultiDataFormatterBase, category: str, expected: str) -> None:
    result = multi_bot.search_all(category)
    assert result == expected



#!/usr/bin/python3
"""
Module for handling year-and-from based category translations.

This module provides classes for formatting template-driven translation labels
that combine temporal patterns (years, decades, centuries) with "from" relation
patterns (e.g., "writers from Yemen", "people from Germany").

The module integrates with category_relation_mapping to resolve relation words
(prepositions like "from", "in", "by") into their Arabic equivalents.

Classes:
    FormatDataFrom: A dynamic wrapper for handling category transformations
        with customizable callbacks for key matching and searching.
    MultiDataFormatterYearAndFrom: Combines year-based and "from" relation
        category translations using the parent class helpers.

Example:
    >>> from ArWikiCats.translations_formats import MultiDataFormatterYearAndFrom, FormatDataFrom
    >>> country_bot = FormatDataFrom(
    ...     formatted_data={"{year1} {country1}": "{country1} في {year1}"},
    ...     key_placeholder="{country1}",
    ...     value_placeholder="{country1}",
    ...     search_callback=get_label_func,
    ...     match_key_callback=match_key_func,
    ... )
    >>> year_bot = FormatDataFrom(
    ...     formatted_data={},
    ...     key_placeholder="{year1}",
    ...     value_placeholder="{year1}",
    ...     search_callback=convert_time_to_arabic,
    ...     match_key_callback=match_time_en_first,
    ... )
    >>> bot = MultiDataFormatterYearAndFrom(country_bot, year_bot, other_key_first=True)
    >>> bot.create_label("14th-century writers from Yemen")
    'كتاب من اليمن في القرن 14'
"""
import re

from ..formats_logger import logger

# from .model_data_time import YearFormatData
from .model_multi_data_base import MultiDataFormatterBaseHelpers


class FormatDataFrom:
    """
    A dynamic wrapper for handling category transformations with customizable callbacks.

    This class provides a flexible way to normalize category strings by extracting
    keys (e.g., year patterns, country names) and replacing them with placeholders.
    It uses callback functions for key matching and searching, allowing customization
    for different category types.

    Attributes:
        formatted_data (dict[str, str]): Mapping of template patterns to Arabic translations.
        formatted_data_ci (dict[str, str]): Case-insensitive version of formatted_data.
        key_placeholder (str): Placeholder string for the key (e.g., "{year1}", "{country1}").
        value_placeholder (str): Placeholder string for the value in Arabic templates.
        search_callback (callable): Function to search/translate a key to its Arabic label.
        match_key_callback (callable): Function to extract a key from a category string.
        fixing_callback (callable | None): Optional callback for post-processing results.

    Example:
        >>> bot = FormatDataFrom(
        ...     formatted_data={"{year1} {country1}": "{country1} في {year1}"},
        ...     key_placeholder="{country1}",
        ...     value_placeholder="{country1}",
        ...     search_callback=lambda x: "كتاب من اليمن" if "yemen" in x.lower() else "",
        ...     match_key_callback=lambda x: x.replace("{year1}", "").strip(),
        ... )
        >>> bot.match_key("{year1} writers from yemen")
        'writers from yemen'
    """

    def __init__(
        self,
        formatted_data: dict[str, str],
        key_placeholder: str,
        value_placeholder: str,
        search_callback: callable,
        match_key_callback: callable,
        fixing_callback: callable = None,
    ) -> None:
        self.search_callback = search_callback
        self.match_key_callback = match_key_callback

        self.key_placeholder = key_placeholder
        self.value_placeholder = value_placeholder
        self.formatted_data = formatted_data
        self.formatted_data_ci = {k.lower(): v for k, v in formatted_data.items()}
        self.fixing_callback = fixing_callback

    def match_key(self, text: str) -> str:
        """Extract English year/decade and return it as the key."""
        return self.match_key_callback(text)

    def normalize_category(self, text: str, key: str) -> str:
        """
        Replace matched year with placeholder.
        normalize_category: key='writers from yemen', text='{year1} writers from yemen'
        """
        logger.debug(f"normalize_category: {key=}, {text=}")
        if not key:
            return text
        result = re.sub(re.escape(key), self.key_placeholder, text, flags=re.IGNORECASE)
        logger.debug(f"normalize_category: {result=}")  # result='{year1} {country1}'
        return result

    def normalize_category_with_key(self, category: str) -> tuple[str, str]:
        """
        Normalize nationality placeholders within a category string.

        Example:
            category:"Yemeni national football teams", result: "natar national football teams"
        """
        key = self.match_key(category)
        result = ""
        if key:
            result = self.normalize_category(category, key)
        return key, result

    def replace_value_placeholder(self, label: str, value: str) -> str:
        # Replace placeholder
        logger.debug(f"!!!! replace_value_placeholder: {self.value_placeholder=}, {label=}, {value=}")
        result = label.replace(self.value_placeholder, value)
        if self.fixing_callback:
            result = self.fixing_callback(result)
        return result

    def get_template_ar(self, template_key: str) -> str:
        """Lookup template in a case-insensitive dict."""
        # Case-insensitive key lookup
        template_key = template_key.lower()
        logger.debug(f"get_template_ar: {template_key=}")
        result = self.formatted_data_ci.get(template_key, "")

        if not result:
            if template_key.startswith("category:"):
                template_key = template_key.replace("category:", "")
                result = self.formatted_data_ci.get(template_key, "")
            else:
                result = self.formatted_data_ci.get(f"category:{template_key}", "")

        logger.debug(f"get_template_ar: {template_key=}, {result=}")
        return result

    def get_key_label(self, key: str) -> str:
        """place holders"""
        if not key:
            return ""
        logger.debug(f"get_key_label: {key=}")
        return self.search(key)

    def search(self, text: str) -> str:
        """place holders"""
        return self.search_callback(text)

    def search_all(self, key: str) -> str:
        """place holders"""
        return self.search(key)


class MultiDataFormatterYearAndFrom(MultiDataFormatterBaseHelpers):
    """
    Combines year-based and "from" relation category translations.

    This class orchestrates two FormatDataFrom instances (country_bot and year_bot)
    to normalize and translate category strings that contain both temporal patterns
    and "from" relation patterns.

    The class integrates with category_relation_mapping to resolve relation words
    (prepositions like "from", "in", "by") into their Arabic equivalents when
    building labels.

    Attributes:
        country_bot (FormatDataFrom): Handles the "from" relation part (e.g., "writers from Yemen").
        other_bot (FormatDataFrom): Handles the year/time part (e.g., "14th-century").
        search_first_part (bool): If True, search using only the first part (after country normalization).
        data_to_find (dict[str, str] | None): Optional direct lookup dictionary for category labels.
        other_key_first (bool): If True, process the year/other key before the country key.

    """

    def __init__(
        self,
        country_bot: FormatDataFrom,
        year_bot: FormatDataFrom,
        search_first_part: bool = False,
        data_to_find: dict[str, str] | None = None,
        other_key_first: bool = False,
    ) -> None:
        """Prepare helpers for matching and formatting template-driven labels.

        Args:
            country_bot: FormatDataFrom instance for handling "from" relation patterns.
            year_bot: FormatDataFrom instance for handling year/time patterns.
            search_first_part: If True, search using only the first part after normalization.
            data_to_find: Optional dictionary for direct category-to-label lookups.
            other_key_first: If True, process year/other key before country key.
        """
        self.search_first_part = search_first_part
        self.country_bot = country_bot
        self.other_bot = year_bot
        self.data_to_find = data_to_find
        self.other_key_first = other_key_first



"""
Mappings used to normalize Arabic category labels.
"""

from __future__ import annotations

from typing import Dict, Set

REPLACEMENTS: Dict[str, str] = {
    "مرشحون يهود في رئيس": "مرشحون يهود لمنصب رئيس",
    "مرشحات في رئيس": "مرشحات لمنصب رئيس",
    "مرشحون في رئيس": "مرشحون لمنصب رئيس",
    "بواسطة البلد": "حسب البلد",
    "المكان المأهول واحتلال": "المكان المأهول والمهنة",
    "حقوق المثليين": "معاملة المثليين",
    "منظمات في أطفال": "منظمات أطفال",
    " تلفزيونية أنمي": " أنمي متلفزة ",
    " تلفزيونية أنيمي": " أنمي متلفزة ",
    "وزارات حكومة في ": "وزارات حكومة ",
    "قضاة من ": "قضاة في ",
    "خصصت ل ": "خصصت ل",
    "متعلقة ب ": "متعلقة ب",
    "معلقو رياضبة": "معلقون رياضيون",
    "ولاية ولاية": "ولاية",
    "ولاية واشنطن العاصمة": "واشنطن العاصمة",
    "الشعر ": "شعر ",
    " و ": " و",
    "جمهورية في ": "جمهورية ",
    "حوادث إرهابية إسلامية": "حوادث إرهابية منسوبة للمسلمين",
    "هجمات إسلامية": "هجمات منسوبة للمسلمين",
}
"""Regex-based replacements applied globally to Arabic labels."""

STARTING_REPLACEMENTS: Dict[str, str] = {
    # "اكتشافات بواسطة" : "اكتشافات",
    "هجمات ضد": "هجمات على",
    "أشخاص أتهموا بتهمة": "متهمون بتهمة",
    "أشخاص أدينوا ب": "مدانون ب",
    "تاريخ تعليم في": "تاريخ التعليم في",
    "أفعال في الكونغرس": "قوانين الكونغرس",
    "أفعال الكونغرس": "قوانين الكونغرس",
    "شهود عيان إلى ": "شهود عيان عن ",
    "أشخاص مرتبطة مع": "أشخاص مرتبطون مع",
    "موقعون من ": "موقعون على ",
    "وفيات من حريق ": "وفيات ناجمة عن الحريق ",
    "معالم أثرية ونصب تذكارية إلى ": "معالم أثرية ونصب تذكارية ل",
    "معالم ونصب تذكارية إلى ": "معالم ونصب تذكارية ل",
    "نصب تذكارية إلى ": "نصب تذكارية عن ",
    "الخط الزمني في ": "الخط الزمني ل",
    "الشعر ": "شعر ",
    "ثقافة في ": "الثقافة في ",
    "تاريخ نقل في ": "تاريخ النقل في ",
    "جوائز التلفاز 1": "جوائز التلفاز في 1",
    "جوائز التلفاز 2": "جوائز التلفاز في 2",
    "تعليم في ": "التعليم في ",
    "هواتف محمولة اخترعت في ": "هواتف محمولة عرضت في ",
    "نقل في ": "النقل في ",
    "وسائل الإعلام انحلت": "وسائل إعلام انحلت",
    "الكتب عن ": "كتب عن ",
    "أحداث الرياضية": "أحداث رياضية",
    "قوائم متعلقة القرن": "قوائم متعلقة بالقرن",
    "قوائم متعلقة عقد": "قوائم متعلقة بعقد",
    "قوائم متعلقة 1": "قوائم متعلقة ب1",
    "قوائم متعلقة 2": "قوائم متعلقة ب2",
    "قوائم متعلقة 3": "قوائم متعلقة ب3",
    "قوائم متعلقة 4": "قوائم متعلقة ب4",
    "قوائم متعلقة 5": "قوائم متعلقة ب5",
    "أفلام 1": "أفلام إنتاج 1",
    "أفلام 2": "أفلام إنتاج 2",
    "أفلام عقد ": "أفلام إنتاج عقد ",
    "أفلام القرن ": "أفلام إنتاج القرن ",
    # "معاهد أبحاث أسست في " : "معاهد أبحاث أسست سنة",
    # "هيئات تعليمية تأسست في": "هيئات تعليمية أسست في",
    "وسائل الإعلام أسست": "وسائل إعلام تأسست",
    "وسائل الإعلام تأسست": "وسائل إعلام تأسست",
    # "أحداث رياضية دورية تأسست": "أحداث رياضية دورية أسست",
}
"""Prefix replacements that run on the start of the label."""

ENDING_REPLACEMENTS: Dict[str, str] = {
    "صناعة إعلامية": "صناعة الإعلام",
    "إلى يونسكو": "لدى يونسكو",
    "إلى الأمم المتحدة": "لدى الأمم المتحدة",
    "إلى منظمة حظر الأسلحة الكيميائية": "لدى منظمة حظر الأسلحة الكيميائية",
    "انتهت في": "انتهت",
    "أنتهت في": "أنتهت",
    "في بإعاقات": "بإعاقات",
    "انتهت حسب السنة": "حسب سنة انتهاء العرض",
    "انتهت حسب العقد": "حسب عقد انتهاء العرض",
    "أنتهت حسب السنة": "حسب سنة انتهاء العرض",
    "بدأ عرضها حسب السنة": "حسب سنة بدء العرض",
    "بدأ عرضها حسب العقد": "حسب عقد بدء العرض",
    "بدأ عرضها حسب القرن": "حسب قرن بدء العرض",
    "في نقل": "في النقل",
    "قتلوا في حركة": "قتلوا في عمليات قتالية",
    "في تعليم": "في التعليم",
    "في أدب": "في الأدب",
    "في تاريخ": "في التاريخ",
    "في طيران": "في الطيران",
    "في ثقافة": "في الثقافة",
    "في رياضة": "في الرياضة",
    "اليابان حسب الولاية": "اليابان حسب المحافظة",
    "في سياسة": "في السياسة",
    "في أفلام": "في الأفلام",
    "في أعمال": "في الأعمال",
    " من": "",
    " في": "",
    "في أحداث رياضية متعددة": "في الأحداث الرياضية المتعددة",
}
"""Suffix replacements applied after trimming whitespace."""

YEAR_CATEGORY_LABELS: Set[str] = {
    "كوارث صحية",
    "كوارث طبيعية",
    "كوارث طبية",
}
"""Labels that require inserting the preposition 'في' before year values."""

__all__ = [
    "REPLACEMENTS",
    "STARTING_REPLACEMENTS",
    "ENDING_REPLACEMENTS",
    "YEAR_CATEGORY_LABELS",
]



#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar

data_1 = {
    "Attacks on diplomatic missions of the United States": "هجمات على بعثات دبلوماسية الولايات المتحدة",
    "Islands of the West Coast of the United States": "جزر الساحل الغربي للولايات المتحدة",
    "Legal history of the United States": "تاريخ الولايات المتحدة القانوني",
    "Lists of ambassadors of the United States": "قوائم سفراء الولايات المتحدة",
    "Lists of amphibians of the United States": "قوائم برمائيات الولايات المتحدة",
    "Lists of animals of the United States": "قوائم حيوانات الولايات المتحدة",
    "Lists of beaches of the United States": "قوائم شواطئ الولايات المتحدة",
    "Lists of biota of the United States": "قوائم حيويات الولايات المتحدة",
    "Lists of birds of the United States": "قوائم طيور الولايات المتحدة",
    "Lists of candidates for President of the United States": "قوائم مرشحون لمنصب رئيس الولايات المتحدة",
    "Lists of caves of the United States": "قوائم كهوف الولايات المتحدة",
    "Geography of the West Coast of the United States": "جغرافيا الساحل الغربي للولايات المتحدة",
    "Heads of state of the United States": "قادة الولايات المتحدة",
    "History of the foreign relations of the United States": "تاريخ علاقات الولايات المتحدة الخارجية",
    "History of the government of the United States": "تاريخ حكومة الولايات المتحدة",
    "History of the Supreme Court of the United States": "تاريخ المحكمة العليا الأمريكية",
    "Finances of presidents of the United States": "مالية رؤساء الولايات المتحدة",
    "Flora of the West Coast of the United States": "نباتات الساحل الغربي للولايات المتحدة",
    "Cultural depictions of presidents of the United States": "تصوير ثقافي عن رؤساء الولايات المتحدة",
    "Children of presidents of the United States": "أبناء رؤساء الولايات المتحدة",
    "Children of vice presidents of the United States": "أبناء نواب رؤساء الولايات المتحدة",
    "Beaches of the West Coast of the United States": "شواطئ الساحل الغربي للولايات المتحدة",
    "Bibliographies of presidents of the United States": "ببليوجرافيات رؤساء الولايات المتحدة",
    "Assassins of presidents of the United States": "منفذو اغتيالات من رؤساء الولايات المتحدة",
    "Assistant Secretaries of Defense of the United States": "مساعدو وزير الدفاع الأمريكي",
    "History of the West Coast of the United States": "تاريخ الساحل الغربي للولايات المتحدة",
    "Lists of fictional presidents of the United States": "قوائم رؤساء الولايات المتحدة الخياليون",
    "Lists of fishes of the United States": "قوائم أسماك الولايات المتحدة",
    "Lists of flags of the United States": "قوائم أعلام الولايات المتحدة",
    "Lists of flora of the United States": "قوائم نباتات الولايات المتحدة",
    "Lists of insects of the United States": "قوائم حشرات الولايات المتحدة",
    "Lists of islands of the United States": "قوائم جزر الولايات المتحدة",
    "Lists of lakes of the United States": "قوائم بحيرات الولايات المتحدة",
    "Lists of landforms of the United States": "قوائم تضاريس الولايات المتحدة",
    "Lists of mammals of the United States": "قوائم ثدييات الولايات المتحدة",
    "Lists of members of the Cabinet of the United States": "قوائم أعضاء مجلس وزراء الولايات المتحدة",
    "Lists of military units and formations of the United States": "قوائم وحدات وتشكيلات الولايات المتحدة العسكرية",
    "Monuments and memorials to presidents of the United States": "معالم أثرية ونصب تذكارية لرؤساء الولايات المتحدة",
    "Physicians to the president of the United States": "أطباء إلى رئيس الولايات المتحدة",
    "Lists of monuments and memorials to presidents of the United States": "قوائم معالم أثرية ونصب تذكارية إلى رؤساء الولايات المتحدة",
    "Lists of mountains of the United States": "قوائم جبال الولايات المتحدة",
    "Lists of reptiles of the United States": "قوائم زواحف الولايات المتحدة",
    "Lists of rivers of the United States": "قوائم أنهار الولايات المتحدة",
    "Lists of ships of the United States": "قوائم سفن الولايات المتحدة",
    "Lists of state governors of the United States": "قوائم حكام ولايات من الولايات المتحدة",
    "Lists of subdivisions of the United States": "قوائم تقسيمات الولايات المتحدة",
    "Members of the Cabinet of the United States": "أعضاء مجلس وزراء الولايات المتحدة",
    "Mistresses of presidents of the United States": "عشيقات رؤساء الولايات المتحدة",
    "Secretaries of agriculture of the United States": "وزراء زراعة أمريكيون",
    "Secretaries of transportation of the United States": "وزراء نقل أمريكيون",
    "Regions of the West Coast of the United States": "مناطق الساحل الغربي للولايات المتحدة",
}

data_2 = {
    "Works about foreign relations of the United States": "أعمال عن علاقات خارجية الولايات المتحدة",
    "Bilateral military relations of the United States": "علاقات الولايات المتحدة الثنائية العسكرية",
    "Bilateral relations of the United States": "علاقات الولايات المتحدة الثنائية",
    "Books about foreign relations of the United States": "كتب عن علاقات خارجية الولايات المتحدة",
    "Works about military history of the United States": "أعمال عن التاريخ العسكري الولايات المتحدة",
    "Works about presidents of the United States": "أعمال عن رؤساء الولايات المتحدة",
    "Works about the military of the United States": "أعمال عن عسكرية الولايات المتحدة",
    "Works by presidents of the United States": "أعمال رؤساء الولايات المتحدة",
    "Men's national sports teams of the United States": "منتخبات رياضية وطنية رجالية الولايات المتحدة",
    "National sports teams of the United States": "منتخبات رياضية وطنية من الولايات المتحدة",
    "National youth sports teams of the United States": "منتخبات رياضية وطنية شبابية الولايات المتحدة",
    "Women's national sports teams of the United States": "منتخبات رياضية وطنية نسائية الولايات المتحدة",
    "Biographical films about presidents of the United States": "أفلام سير ذاتية عن رؤساء الولايات المتحدة",
    "Documentary films about presidents of the United States": "أفلام وثائقية عن رؤساء الولايات المتحدة",
    "Films about fictional presidents of the United States": "أفلام عن رؤساء خياليون الولايات المتحدة",
    "Films about presidents of the United States": "أفلام عن رؤساء الولايات المتحدة",
    "Candidates for President of the United States": "مرشحون لمنصب رئيس الولايات المتحدة",
    "Jewish candidates for President of the United States": "مرشحون يهود لمنصب رئيس الولايات المتحدة",
    "Female candidates for President of the United States": "مرشحات لمنصب رئيس الولايات المتحدة",
    "Books about politics of the United States": "كتب عن سياسة الولايات المتحدة",
    "Books about presidents of the United States": "كتب عن رؤساء الولايات المتحدة",
    "Books about the economy of the United States": "كتب عن اقتصاد الولايات المتحدة",
    "Categories by language of the United States": "تصنيفات حسب لغة الولايات المتحدة",
    "Cinema by language of the United States": "سينما حسب لغة الولايات المتحدة",
    "Mass media by language of the United States": "وسائل إعلام حسب لغة الولايات المتحدة",
    "Books written by presidents of the United States": "كتب كتبها رؤساء الولايات المتحدة",
    "Children's books about presidents of the United States": "كتب أطفال عن رؤساء الولايات المتحدة",
    "Non-fiction books about military history of the United States": "كتب غير خيالية عن التاريخ العسكري الولايات المتحدة",
    "Songs about presidents of the United States": "أغاني عن رؤساء الولايات المتحدة",
    "Television series about presidents of the United States": "مسلسلات تلفزيونية عن رؤساء الولايات المتحدة",
    "Television series about the history of the United States": "مسلسلات تلفزيونية عن تاريخ الولايات المتحدة",
    "Conspiracy theories involving presidents of the United States": "نظريات مؤامرة تشمل رؤساء الولايات المتحدة",
}

data_3 = {
    "Cultural history of the United States": "تاريخ الولايات المتحدة الثقافي",
    "Demographic history of the United States": "تاريخ الولايات المتحدة الديموغرافي",
    "Economic history of the United States": "تاريخ الولايات المتحدة الاقتصادي",
    "History of the United States": "تاريخ الولايات المتحدة",
    "Maritime history of the United States": "تاريخ الولايات المتحدة البحري",
    "Military history of the United States": "تاريخ الولايات المتحدة العسكري",
    "Nuclear history of the United States": "تاريخ الولايات المتحدة النووي",
    "Political history of the United States": "تاريخ الولايات المتحدة السياسي",
    "Prehistory of the United States": "الولايات المتحدة ما قبل التاريخ",
    "Social history of the United States": "تاريخ الولايات المتحدة الاجتماعي",
    "Acting presidents of the United States": "رؤساء الولايات المتحدة بالإنابة",
    "Ambassadors of the United States": "سفراء الولايات المتحدة",
    "Amphibians of the United States": "برمائيات الولايات المتحدة",
    "Arachnids of the United States": "عنكبيات الولايات المتحدة",
    "Archipelagoes of the United States": "أرخبيلات الولايات المتحدة",
    "Arthropods of the United States": "مفصليات الولايات المتحدة",
    "Attorneys general of the United States": "مدعون عامون من الولايات المتحدة",
    "Banks of the United States": "بنوك الولايات المتحدة",
    "Bats of the United States": "خفاشيات الولايات المتحدة",
    "Bays of the United States": "خلجان الولايات المتحدة",
    "Beaches of the United States": "شواطئ الولايات المتحدة",
    "Bilateral treaties of the United States": "معاهدات الولايات المتحدة الثنائية",
    "Biota of the United States": "حيويات الولايات المتحدة",
    "Birds of the United States": "طيور الولايات المتحدة",
    "Borders of the United States": "حدود الولايات المتحدة",
    "Cabinet of the United States": "مجلس وزراء الولايات المتحدة",
    "Cacti of the United States": "صباريات الولايات المتحدة",
    "Cargo ships of the United States": "سفن بضائع الولايات المتحدة",
    "Caves of the United States": "كهوف الولايات المتحدة",
    "Chief justices of the United States": "رؤساء قضاء الولايات المتحدة",
    "Cliffs of the United States": "منحدرات الولايات المتحدة",
    "Climate of the United States": "مناخ الولايات المتحدة",
    "Coachbuilders of the United States": "صانعو هياكل سيارات من الولايات المتحدة",
    "Coasts of the United States": "سواحل الولايات المتحدة",
    "Crustaceans of the United States": "قشريات الولايات المتحدة",
    "Culture of the United States": "ثقافة الولايات المتحدة",
    "Deserts of the United States": "صحاري الولايات المتحدة",
    "Diplomatic missions of the United States": "بعثات الولايات المتحدة الدبلوماسية",
    "Economy of the United States": "اقتصاد الولايات المتحدة",
    "Environment of the United States": "بيئة الولايات المتحدة",
    "Explorers of the United States": "مستكشفو الولايات المتحدة",
    "Extrajudicial prisoners of the United States": "مسجونون خارج نطاق القضاء من الولايات المتحدة",
    "Fauna of the United States": "حيوانات الولايات المتحدة",
    "Featured pictures of the United States": "صور مميزة عن الولايات المتحدة",
    "Fictional presidents of the United States": "رؤساء الولايات المتحدة الخياليون",
    "Fish of the United States": "أسماك الولايات المتحدة",
    "Flags of the United States": "أعلام الولايات المتحدة",
    "Flora of the United States": "نباتات الولايات المتحدة",
    "Foreign relations of the United States": "علاقات الولايات المتحدة الخارجية",
    "Forests of the United States": "غابات الولايات المتحدة",
    "Fungi of the United States": "فطريات الولايات المتحدة",
    "Geography of the United States": "جغرافيا الولايات المتحدة",
    "Geology of the United States": "جيولوجيا الولايات المتحدة",
    "Government of the United States": "حكومة الولايات المتحدة",
    "Gulfs of the United States": "خلجان الولايات المتحدة",
    "Hills of the United States": "تلال الولايات المتحدة",
    "Historians of the United States": "مؤرخو الولايات المتحدة",
    "Historiography of the United States": "تأريخ الولايات المتحدة",
    "Hot springs of the United States": "ينابيع حارة في الولايات المتحدة",
    "Images of the United States": "صور من الولايات المتحدة",
    "Insects of the United States": "حشرات الولايات المتحدة",
    "Invertebrates of the United States": "لافقاريات الولايات المتحدة",
    "Islands of the United States": "جزر الولايات المتحدة",
    "Lakes of the United States": "بحيرات الولايات المتحدة",
    "Landforms of the United States": "تضاريس الولايات المتحدة",
    "Languages of the United States": "لغات الولايات المتحدة",
    "Mammals of the United States": "ثدييات الولايات المتحدة",
    "Military equipment of the United States": "عتاد الولايات المتحدة العسكري",
    "Military installations of the United States": "منشآت الولايات المتحدة العسكرية",
    "Military of the United States": "عسكرية الولايات المتحدة",
    "Military units and formations of the United States": "وحدات وتشكيلات الولايات المتحدة العسكرية",
    "Molluscs of the United States": "رخويات الولايات المتحدة",
    "Mountains of the United States": "جبال الولايات المتحدة",
    "Music of the United States": "موسيقى الولايات المتحدة",
    "National debt of the United States": "الدين العام الأمريكي",
    "National symbols of the United States": "رموز الولايات المتحدة الوطنية",
    "Orders, decorations, and medals of the United States": "مراتب تشريفية وأوسمة وميداليات الولايات المتحدة",
    "Peace treaties of the United States": "معاهدات سلام الولايات المتحدة",
    "Plains of the United States": "سهول الولايات المتحدة",
    "Plateaus of the United States": "هضاب الولايات المتحدة",
    "Politics of the United States": "سياسة الولايات المتحدة",
    "Presidencies of the United States": "رئاسات الولايات المتحدة",
    "Presidency of the United States": "رئاسة الولايات المتحدة",
    "Presidents of the United States": "رؤساء الولايات المتحدة",
    "Reefs of the United States": "شعاب الولايات المتحدة",
    "Regions of the United States": "مناطق الولايات المتحدة",
    "Reptiles of the United States": "زواحف الولايات المتحدة",
    "Rivers of the United States": "أنهار الولايات المتحدة",
    "Rodents of the United States": "قوارض الولايات المتحدة",
    "Satellites of the United States": "أقمار صناعية تتبع الولايات المتحدة",
    "Seas of the United States": "بحار الولايات المتحدة",
    "Ships of the United States": "سفن الولايات المتحدة",
    "Society of the United States": "مجتمع الولايات المتحدة",
    "Springs of the United States": "ينابيع الولايات المتحدة",
    "State appellate courts of the United States": "محاكم استئناف ولايات الولايات المتحدة",
    "State cabinet secretaries of the United States": "أعضاء مجلس وزراء الولايات المتحدة",
    "State governors of the United States": "حكام ولايات من الولايات المتحدة",
    "State legislators of the United States": "مشرعو الولايات من الولايات المتحدة",
    "State treasurers of the United States": "أمناء خزينة ولاية الولايات المتحدة",
    "Straits of the United States": "مضائق الولايات المتحدة",
    "Submarines of the United States": "غواصات الولايات المتحدة",
    "Tanks of the United States": "دبابات الولايات المتحدة",
    "Treasurers of the United States": "أمناء خزينة الولايات المتحدة",
    "Treaties of the United States": "معاهدات الولايات المتحدة",
    "Valleys of the United States": "أودية الولايات المتحدة",
    "Vehicles of the United States": "مركبات الولايات المتحدة",
    "Vertebrates of the United States": "فقاريات الولايات المتحدة",
    "Vice presidency of the United States": "نائب رئاسة الولايات المتحدة",
    "Vice presidents of the United States": "نواب رؤساء الولايات المتحدة",
    "Volcanoes of the United States": "براكين الولايات المتحدة",
    "Waterfalls of the United States": "شلالات الولايات المتحدة",
}


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    # ("test_1", data_1),
    # ("test_2", data_2),
    ("test_3", data_3),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new.resolve_films_bots.resolve_films_labels_and_time import get_films_key_tyty_new_and_time

fast_data_with_nats = {
    "northern ireland": "",
    "northern ireland films 2020": "",
    "2020 northern ireland films": "أفلام أيرلندية شمالية في 2020",
    "2020 northern ireland": "",
    "2020 Australian children's animated superhero film characters": "شخصيات أفلام رسوم متحركة أبطال خارقين أسترالية للأطفال في 2020",
    "20th-century supernatural thriller films": "أفلام إثارة خارقة للطبيعة في القرن 20",
    "20th-century american animated short television series": "مسلسلات تلفزيونية رسوم متحركة قصيرة أمريكية في القرن 20",
    "20th-century american drama television series": "مسلسلات تلفزيونية درامية أمريكية في القرن 20",
    # nats
    "20th-century action classical albums": "ألبومات كلاسيكية حركة في القرن 20",
    "20th-century yemeni action classical albums": "ألبومات كلاسيكية حركة يمنية في القرن 20",
    "20th-century yemeni novellas": "روايات قصيرة يمنية في القرن 20",
    "20th-century yemeni films": "أفلام يمنية في القرن 20",
    "20th-century Yemeni action films": "أفلام حركة يمنية في القرن 20",
    "20th-century Yemeni action drama films": "أفلام حركة درامية يمنية في القرن 20",
    "20th-century Yemeni upcoming horror films": "أفلام رعب قادمة يمنية في القرن 20",
    "20th-century Yemeni horror upcoming films": "أفلام رعب قادمة يمنية في القرن 20",
    "20th-century Yemeni upcoming films": "أفلام قادمة يمنية في القرن 20",
    "20th-century heist japanese horror films": "أفلام سرقة رعب يابانية في القرن 20",
    "20th-century Yemeni action thriller adult animated supernatural films": "أفلام إثارة حركة رسوم متحركة خارقة للطبيعة للكبار يمنية في القرن 20",
}

fast_data_no_nats = {
    # films keys
    "2020s 3d low-budget films": "أفلام ثلاثية الأبعاد منخفضة التكلفة في عقد 2020",
    "2020s low-budget 3d films": "أفلام ثلاثية الأبعاد منخفضة التكلفة في عقد 2020",
    "2020s heist historical television commercials": "إعلانات تجارية تلفزيونية سرقة تاريخية في عقد 2020",
    "2020s adult animated supernatural films": "أفلام رسوم متحركة خارقة للطبيعة للكبار في عقد 2020",
    "2020s heist holocaust films": "أفلام سرقة هولوكوستية في عقد 2020",
    "2020s heist hood films": "أفلام سرقة هود في عقد 2020",
    "2020s heist horror films": "أفلام سرقة رعب في عقد 2020",
    "2020s heist independent films": "أفلام سرقة مستقلة في عقد 2020",
    "2020s heist interactive films": "أفلام سرقة تفاعلية في عقد 2020",
    "2020s heist internet films": "أفلام سرقة إنترنت في عقد 2020",
    "2020s heist joker films": "أفلام سرقة جوكر في عقد 2020",
    "2020s heist kaiju films": "أفلام سرقة كايجو في عقد 2020",
    "20th-century heist kung fu films": "أفلام سرقة كونغ فو في القرن 20",
    "20th-century heist latin films": "أفلام سرقة لاتينية في القرن 20",
    "20th-century heist legal films": "أفلام سرقة قانونية في القرن 20",
    "20th-century psychological horror black-and-white films": "أفلام رعب نفسي أبيض وأسود في القرن 20",
    "20th-century psychological horror bollywood films": "أفلام رعب نفسي بوليوود في القرن 20",
    "20th-century action sports films": "أفلام حركة رياضية في القرن 20",
    "20th-century action spy films": "أفلام حركة تجسسية في القرن 20",
    "20th-century action street fighter films": "أفلام حركة قتال شوارع في القرن 20",
    "20th-century action student films": "أفلام حركة طلاب في القرن 20",
    "20th-century action submarines films": "أفلام حركة غواصات في القرن 20",
    "20th-century action super robot films": "أفلام حركة آلية خارقة في القرن 20",
    "20th-century action superhero films": "أفلام حركة أبطال خارقين في القرن 20",
    "20th-century action supernatural films": "أفلام حركة خارقة للطبيعة في القرن 20",
    "20th-century action supernatural drama films": "أفلام حركة دراما خارقة للطبيعة في القرن 20",
    "20th-century action survival films": "أفلام حركة البقاء على قيد الحياة في القرن 20",
    "20th-century action teen films": "أفلام حركة مراهقة في القرن 20",
    "20th-century action thriller 3d films": "أفلام إثارة حركة ثلاثية الأبعاد في القرن 20",
    "20th-century action thriller 4d films": "أفلام إثارة حركة رباعية الأبعاد في القرن 20",
    "20th-century action thriller action films": "أفلام إثارة حركة حركة في القرن 20",
    "20th-century action thriller action comedy films": "أفلام إثارة حركة حركة كوميدية في القرن 20",
    "20th-century action thriller adaptation films": "أفلام إثارة حركة مقتبسة في القرن 20",
    "20th-century action thriller adult animated films": "أفلام إثارة حركة رسوم متحركة للكبار في القرن 20",
    "20th-century action thriller adult animated drama films": "أفلام إثارة حركة رسوم متحركة دراما للكبار في القرن 20",
    "20th-century action thriller adult animated supernatural films": "أفلام إثارة حركة رسوم متحركة خارقة للطبيعة للكبار في القرن 20",
    "20th-century action thriller adventure films": "أفلام إثارة حركة مغامرات في القرن 20",
    "20th-century action thriller animated films": "أفلام إثارة حركة رسوم متحركة في القرن 20",
    "20th-century action thriller animated science films": "أفلام إثارة حركة علمية رسوم متحركة في القرن 20",
    "20th-century action thriller animated short films": "أفلام إثارة حركة رسوم متحركة قصيرة في القرن 20",
    "20th-century psychological horror buddy films": "أفلام رعب نفسي رفقاء في القرن 20",
    "2010 psychological horror cancelled films": "أفلام رعب نفسي ملغية في 2010",
}


@pytest.mark.parametrize("category, expected", fast_data_no_nats.items(), ids=fast_data_no_nats.keys())
@pytest.mark.fast
def test_get_films_key_tyty(category: str, expected: str) -> None:
    label2 = get_films_key_tyty_new_and_time(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", fast_data_with_nats.items(), ids=fast_data_with_nats.keys())
@pytest.mark.fast
def test_fast_data_with_nats(category: str, expected: str) -> None:
    label2 = get_films_key_tyty_new_and_time(category)
    assert label2 == expected


to_test = [
    ("test_get_films_key_tyty", fast_data_no_nats, get_films_key_tyty_new_and_time),
    ("test_fast_data_with_nats", fast_data_with_nats, get_films_key_tyty_new_and_time),
]


@pytest.mark.parametrize("name,data, callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
Resolve medalists categories translations
"""
import functools
from typing import Dict

from ...helps import logger
from ...translations import COUNTRY_LABEL_OVERRIDES, countries_from_nat
from ...translations_formats import MultiDataFormatterBaseV2, format_multi_data_v2

medalists_data = {
    # "central american and caribbean games": "ألعاب أمريكا الوسطى والكاريبي",
    "afc asian cup finals": "نهائيات كأس آسيا",
    "afc asian cup qualification": "تصفيات كأس آسيا",
    "afc asian cup": "كأس آسيا",
    "afc challenge league": "دوري التحدي الآسيوي",
    "afc champions league elite": "دوري نخبة ابطال آسيا",
    "afc champions league two": "دوري أبطال آسيا الثاني",
    "afc champions league": "دوري أبطال آسيا",
    "afc cup participants": "مشاركون في كأس الاتحاد الآسيوي لكرة القدم",
    "afc cup": "كأس الاتحاد الآسيوي",
    "afc elite league": "دوري نخبة ابطال آسيا",
    "afc football": "كرة قدم الاتحاد الآسيوي لكرة القدم",
    "afc futsal asian cup": "كأس آسيا لكرة الصالات",
    "afc futsal championship": "بطولة آسيا لكرة الصالات",
    "afc futsal club championship": "بطولة آسيا لكرة الصالات للأندية",
    "afc president's cup": "كأس رئيس الاتحاد الآسيوي",
    "afc solidarity cup": "كأس التضامن الآسيوي",
    "afc u-16 asian cup": "كأس آسيا للناشئين تحت 16 سنة",
    "afc u-16 championship": "بطولة آسيا للناشئين تحت 16 سنة",
    "afc u-16 women's asian cup": "كأس آسيا للسيدات تحت 16 سنة",
    "afc u-16 women's championship": "بطولة آسيا للسيدات تحت 16 سنة",
    "afc u-17 asian cup": "كأس آسيا للناشئين تحت 17 سنة",
    "afc u-17 championship": "بطولة آسيا للناشئين تحت 17 سنة",
    "afc u-17 women's asian cup": "كأس آسيا للسيدات تحت 17 سنة",
    "afc u-17 women's championship": "بطولة آسيا للسيدات تحت 17 سنة",
    "afc u-19 asian cup": "كأس آسيا للناشئين تحت 19 سنة",
    "afc u-19 championship": "بطولة آسيا للناشئين تحت 19 سنة",
    "afc u-19 women's asian cup": "كأس آسيا للسيدات تحت 19 سنة",
    "afc u-19 women's championship": "بطولة آسيا للسيدات تحت 19 سنة",
    "afc u-20 asian cup": "كأس آسيا للناشئين تحت 20 سنة",
    "afc u-20 championship": "بطولة آسيا للناشئين تحت 20 سنة",
    "afc u-20 women's asian cup": "كأس آسيا للسيدات تحت 20 سنة",
    "afc u-20 women's championship": "بطولة آسيا للسيدات تحت 20 سنة",
    "afc u-22 asian cup": "كأس آسيا للناشئين تحت 22 سنة",
    "afc u-22 championship": "بطولة آسيا للناشئين تحت 22 سنة",
    "afc u-22 women's asian cup": "كأس آسيا للسيدات تحت 22 سنة",
    "afc u-22 women's championship": "بطولة آسيا للسيدات تحت 22 سنة",
    "afc u-23 asian cup": "كأس آسيا تحت 23 سنة",
    "afc u-23 championship": "بطولة آسيا تحت 23 سنة",
    "afc u-23 women's asian cup": "كأس آسيا للسيدات تحت 23 سنة",
    "afc u-23 women's championship": "بطولة آسيا للسيدات تحت 23 سنة",
    "afc women's asian cup": "كأس الأمم الآسيوية لكرة القدم للسيدات",
    "afc women's championship": "بطولة آسيا للسيدات",
    "afc women's futsal championship": "بطولة آسيا لكرة الصالات للسيدات",
    "afc youth championship": "بطولة آسيا للشباب",
    "african games": "الألعاب الإفريقية",
    "all-africa games": "ألعاب عموم إفريقيا",
    "asian beach games": "دورة الألعاب الآسيوية الشاطئية",
    "asian football confederation": "الاتحاد الآسيوي لكرة القدم",
    "asian games": "الألعاب الآسيوية",
    "asian indoor games": "دورة الألعاب الآسيوية داخل الصالات",
    "asian para games": "الألعاب البارالمبية الآسيوية",
    "asian summer games": "الألعاب الآسيوية الصيفية",
    "asian winter games": "الألعاب الآسيوية الشتوية",
    "association football afc": "كرة القدم في الاتحاد الآسيوي لكرة القدم",
    "association-football afc": "كرة القدم في الاتحاد الآسيوي لكرة القدم",
    "bolivarian games": "الألعاب البوليفارية",
    "central american and caribbean games": "ألعاب أمريكا الوسطى والكاريبي",
    "central american games": "ألعاب أمريكا الوسطى",
    "central-american-and-caribbean-games": "ألعاب أمريكا الوسطى والكاريبي",
    "commonwealth games": "ألعاب الكومنولث",
    "commonwealth youth games": "ألعاب الكومنولث الشبابية",
    "deaflympic games": "ألعاب ديفلمبياد",
    "european games": "الألعاب الأوروبية",
    "european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية",
    "fifa futsal world cup qualification (afc)": "تصفيات كأس العالم لكرة الصالات (آسيا)",
    "fifa futsal world cup qualification (caf)": "تصفيات كأس العالم لكرة الصالات (إفريقيا)",
    "fifa futsal world cup qualification": "تصفيات كأس العالم لكرة الصالات",
    "fifa futsal world cup": "كأس العالم لكرة الصالات",
    "fifa world cup qualification (afc)": "تصفيات كأس العالم لكرة القدم (آسيا)",
    "fifa world cup qualification (caf)": "تصفيات كأس العالم لكرة القدم (إفريقيا)",
    "fis nordic world ski championships": "بطولة العالم للتزلج النوردي على الثلج",
    "friendship games": "ألعاب الصداقة",
    "goodwill games": "ألعاب النوايا الحسنة",
    "islamic solidarity games": "ألعاب التضامن الإسلامي",
    "jeux de la francophonie": "الألعاب الفرانكوفونية",
    "maccabiah games": "الألعاب المكابيه",
    "mediterranean games": "الألعاب المتوسطية",
    "micronesian games": "الألعاب الميكرونيزية",
    "military world games": "دورة الألعاب العسكرية",
    "olympic games": "الألعاب الأولمبية",
    "olympic": "الألعاب الأولمبية",
    "pan american games": "دورة الألعاب الأمريكية",
    "pan arab games": "دورة الألعاب العربية",
    "pan asian games": "دورة الألعاب الآسيوية",
    "paralympic": "الألعاب البارالمبية",
    "paralympics games": "الألعاب البارالمبية",
    "paralympics": "الألعاب البارالمبية",
    "parapan american games": "ألعاب بارابان الأمريكية",
    "sea games": "ألعاب البحر",
    "south american games": "ألعاب أمريكا الجنوبية",
    "south asian beach games": "دورة ألعاب جنوب أسيا الشاطئية",
    "south asian games": "ألعاب جنوب أسيا",
    "south asian winter games": "ألعاب جنوب آسيا الشتوية",
    # "winter olympic": "الألعاب الأولمبية الشتوية",
    # "winter universiade": "الألعاب الجامعية الشتوية",
    # "winter world university games": "ألعاب الجامعات العالمية الشتوية",
    # "summer olympic": "الألعاب الأولمبية الصيفية",
    # "summer universiade": "الألعاب الجامعية الصيفية",
    # "summer world university games": "ألعاب الجامعات العالمية الصيفية",
    "southeast asian games": "ألعاب جنوب شرق آسيا",
    "the universiade": "الألعاب الجامعية",
    "universiade": "الألعاب الجامعية",
    "world athletics indoor championships": "بطولة العالم لألعاب القوى داخل الصالات",
    "world championships": "بطولات العالم",
    "world games": "دورة الألعاب العالمية",
    "world university games": "ألعاب الجامعات العالمية",
    "youth olympic games": "الألعاب الأولمبية الشبابية",
    "youth olympic": "الألعاب الأولمبية الشبابية",
}


def _build_formatted_data() -> Dict[str, str]:
    # NOTE: formatted_data used in other resolver
    formatted_data: Dict[str, str] = {}

    base_formatted_data = {
        "{en} at {game_en}": "{ar} في {game_ar}",
        "{game_en}": "{game_ar}",
        "{game_en} coaches": "مدربون في {game_ar}",
        "{game_en} managers": "مدربون في {game_ar}",
        "{game_en} competitors": "منافسون في {game_ar}",
        "{game_en} competitors for {en}": "منافسون في {game_ar} من {ar}",
        "{game_en} competitions": "منافسات {game_ar}",
        "{game_en} events": "أحداث {game_ar}",
        "{game_en} festival": "مهرجانات {game_ar}",
        "{game_en} bids": "عروض {game_ar}",
        "{game_en} templates": "قوالب {game_ar}",
        "{game_en} medalists": "فائزون بميداليات {game_ar}",
        "{game_en} bronze medalists": "فائزون بميداليات برونزية في {game_ar}",
        "{game_en} gold medalists": "فائزون بميداليات ذهبية في {game_ar}",
        "{game_en} silver medalists": "فائزون بميداليات فضية في {game_ar}",
        "{game_en} medalists for {en}": "فائزون بميداليات {game_ar} من {ar}",
        "{game_en} bronze medalists for {en}": "فائزون بميداليات برونزية في {game_ar} من {ar}",
        "{game_en} gold medalists for {en}": "فائزون بميداليات ذهبية في {game_ar} من {ar}",
        "{game_en} silver medalists for {en}": "فائزون بميداليات فضية في {game_ar} من {ar}",
    }

    for base_key, base_label in base_formatted_data.items():
        formatted_data[base_key] = base_label
        # formatted_data[f"winter {base_key}"] = f"{base_label} الشتوية"
        formatted_data[f"winter {base_key}"] = base_label.format(game_ar="{game_ar} الشتوية", ar="{ar}")
        formatted_data[f"summer {base_key}"] = base_label.format(game_ar="{game_ar} الصيفية", ar="{ar}")
        formatted_data[f"west {base_key}"] = base_label.format(game_ar="{game_ar} الغربية", ar="{ar}")
        formatted_data[f"east {base_key}"] = base_label.format(game_ar="{game_ar} الشرقية", ar="{ar}")

    olympic_types = {
        "olympic": "أولمبية",
        "winter olympic": "أولمبية شتوية",
        "summer olympic": "أولمبية صيفية",
        "paralympic": "بارالمبية",
    }
    formatted_data.update(
        {
            "olympic gold medalists for {en} in alpine skiing": "فائزون بميداليات ذهبية أولمبية من {ar} في التزلج على المنحدرات الثلجية",
            # medalists
            "olympic medalists": "فائزون بميداليات أولمبية",
            "olympic gold medalists": "فائزون بميداليات ذهبية أولمبية",
            "olympic silver medalists": "فائزون بميداليات فضية أولمبية",
            "olympic bronze medalists": "فائزون بميداليات برونزية أولمبية",
            "winter olympic medalists": "فائزون بميداليات أولمبية شتوية",
            "summer olympic medalists": "فائزون بميداليات أولمبية صيفية",
            # medalists + countries
            "olympic medalists for {en}": "فائزون بميداليات أولمبية من {ar}",
            "olympic gold medalists for {en}": "فائزون بميداليات ذهبية أولمبية من {ar}",
            "olympic silver medalists for {en}": "فائزون بميداليات فضية أولمبية من {ar}",
            "olympic bronze medalists for {en}": "فائزون بميداليات برونزية أولمبية من {ar}",
            # competitors
            "paralympic competitors": "منافسون بارالمبيون",
            "olympic competitors": "منافسون أولمبيون",
            "winter olympic competitors": "منافسون أولمبيون شتويون",
            "summer olympic competitors": "منافسون أولمبيون صيفيون",
            # competitors + countries
            "paralympic competitors for {en}": "منافسون بارالمبيون من {ar}",
            "olympic competitors for {en}": "منافسون أولمبيون من {ar}",
            "winter olympic competitors for {en}": "منافسون أولمبيون شتويون من {ar}",
            "summer olympic competitors for {en}": "منافسون أولمبيون صيفيون من {ar}",
        }
    )

    return formatted_data


@functools.lru_cache(maxsize=1)
def _load_bot() -> MultiDataFormatterBaseV2:
    countries_from_nat_data = countries_from_nat | COUNTRY_LABEL_OVERRIDES
    countries_data = {x: {"ar": v} for x, v in countries_from_nat_data.items()}
    sports_data = {
        x: {
            "game_ar": v,
        }
        for x, v in medalists_data.items()
    }
    formatted_data = _build_formatted_data()

    r"""both_bot_ = format_multi_data_v2(
        formatted_data=formatted_data,
        data_list=sports_data,
        key_placeholder="{game_en}",
        data_list2=countries_data,
        key2_placeholder="{en}",
        text_after="",
        text_before="the ",
        regex_filter=r"[\w-]",
        search_first_part=True,
        use_other_formatted_data=True,
    )"""

    both_bot = format_multi_data_v2(
        formatted_data=formatted_data,
        data_list=countries_data,
        key_placeholder="{en}",
        data_list2=sports_data,
        key2_placeholder="{game_en}",
        text_after="",
        text_before="the ",
        regex_filter=r"[\w-]",
        search_first_part=True,
        use_other_formatted_data=True,
    )
    return both_bot


def fix_keys(category: str) -> str:
    normalized_category = category.lower()
    replacements = {
        "medallists": "medalists",
        "olympics": "olympic",
    }

    for old, new in replacements.items():
        normalized_category = normalized_category.replace(old, new)

    return normalized_category


@functools.lru_cache(maxsize=10000)
def resolve_countries_names_medalists(category: str) -> str:
    normalized_category = fix_keys(category)
    logger.debug(f"<<yellow>> start resolve_countries_names_medalists: {normalized_category=}")

    nat_bot = _load_bot()
    result = nat_bot.search_all_category(normalized_category)

    logger.info_if_or_debug(
        f"<<yellow>> end resolve_countries_names_medalists: {normalized_category=}, {result=}", result
    )
    return result


__all__ = [
    "resolve_countries_names_medalists",
]



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

non_fiction_data_by = {
    "Category:Turkish non-fiction writers by century": "تصنيف:كتاب غير روائيين أتراك حسب القرن",
    "Category:Australian non-fiction writers by century": "تصنيف:كتاب غير روائيين أستراليون حسب القرن",
    "Category:Brazilian non-fiction writers by century": "تصنيف:كتاب غير روائيين برازيليون حسب القرن",
    "Category:Portuguese non-fiction writers by century": "تصنيف:كتاب غير روائيين برتغاليون حسب القرن",
    "Category:Puerto Rican non-fiction writers by century": "تصنيف:كتاب غير روائيين بورتوريكيون حسب القرن",
    "Category:Czech non-fiction writers by century": "تصنيف:كتاب غير روائيين تشيكيون حسب القرن",
    "Category:Welsh non-fiction writers by century": "تصنيف:كتاب غير روائيين ويلزيون حسب القرن",
    "Category:Jewish non-fiction writers by nationality": "تصنيف:كتاب غير روائيين يهود حسب الجنسية",
    "Category:Greek non-fiction writers by century": "تصنيف:كتاب غير روائيين يونانيون حسب القرن",
    "Category:Mexican non-fiction writers by century": "تصنيف:كتاب غير روائيين مكسيكيون حسب القرن",
    "Category:Non-fiction writers from Northern Ireland by century": "تصنيف:كتاب غير روائيين من أيرلندا الشمالية حسب القرن",
    "Category:Non-fiction writers by ethnicity": "تصنيف:كتاب غير روائيين حسب المجموعة العرقية",
    "Category:17th-century non-fiction writers by nationality": "تصنيف:كتاب غير روائيين في القرن 17 حسب الجنسية",
    "Category:18th-century non-fiction writers by nationality": "تصنيف:كتاب غير روائيين في القرن 18 حسب الجنسية",
}

non_fiction_data_from = {
    "Category:20th-century non-fiction writers from Northern Ireland": "تصنيف:كتاب غير روائيين من أيرلندا الشمالية في القرن 20",
    "Category:18th-century non-fiction writers from the Russian Empire": "تصنيف:كتاب غير روائيين من الإمبراطورية الروسية في القرن 18",
}

non_fiction_data_nats = {
    "Category:Salvadoran non-fiction writers": "تصنيف:كتاب غير روائيين سلفادوريون",
    "Category:Non-fiction writers about the United States": "تصنيف:كتاب غير روائيين عن الولايات المتحدة",
    "Category:Non-fiction writers about organized crime": "تصنيف:كتاب غير روائيين عن جريمة منظمة",
    "Category:Non-fiction writers about California": "تصنيف:كتاب غير روائيين عن كاليفورنيا",
    "Category:Croatian non-fiction writers": "تصنيف:كتاب غير روائيين كروات",
    "Category:Moldovan non-fiction writers": "تصنيف:كتاب غير روائيين مولدوفيون",
    "Category:Nepalese non-fiction writers": "تصنيف:كتاب غير روائيين نيباليون",
    "Category:Nicaraguan non-fiction writers": "تصنيف:كتاب غير روائيين نيكاراغويون",
    "Category:British non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين بريطانيون",
    "Category:Jordanian non-fiction writers": "تصنيف:كتاب غير روائيين أردنيون",
    "Category:Bahraini non-fiction writers": "تصنيف:كتاب غير روائيين بحرينيون",
    "Category:Bulgarian non-fiction writers": "تصنيف:كتاب غير روائيين بلغاريون",
    "Category:Panamanian non-fiction writers": "تصنيف:كتاب غير روائيين بنميون",
    "Category:Burundian non-fiction writers": "تصنيف:كتاب غير روائيين بورونديون",
    "Category:Gibraltarian non-fiction writers": "تصنيف:كتاب غير روائيين جبل طارقيون",
    "Category:Algerian non-fiction writers": "تصنيف:كتاب غير روائيين جزائريون",
}

non_fiction_data_male = {
    # "Category:New Zealand male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور نيوزيلنديون",
    "Category:Turkish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أتراك",
    "Category:Argentine male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أرجنتينيون",
    "Category:Albanian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ألبان",
    "Category:Estonian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إستونيون",
    "Category:Israeli male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إسرائيليون",
    "Category:Scottish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إسكتلنديون",
    "Category:Pakistani male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور باكستانيون",
    "Category:Brazilian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور برازيليون",
    "Category:Portuguese male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور برتغاليون",
    "Category:Puerto Rican male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بورتوريكيون",
    "Category:Bolivian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بوليفيون",
    "Category:Peruvian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بيرويون",
    "Category:Trinidad and Tobago male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ترنيداديون",
    "Category:Czech male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور تشيكيون",
    "Category:Chilean male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور تشيليون",
    "Category:Jamaican male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور جامايكيون",
    "Category:Russian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور روس",
    "Category:Romanian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور رومان",
    "Category:Soviet male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور سوفيت",
    "Category:Swiss male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور سويسريون",
    "Category:Serbian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور صرب",
    "Category:Chinese male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور صينيون",
    "Category:Palestinian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور فلسطينيون",
    "Category:Venezuelan male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور فنزويليون",
    "Category:Finnish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور فنلنديون",
    "Category:Cuban male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور كوبيون",
    "Category:Colombian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور كولومبيون",
    "Category:Luxembourgian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور لوكسمبورغيون",
    "Category:Lithuanian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ليتوانيون",
    "Category:Hungarian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مجريون",
    "Category:Egyptian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مصريون",
    "Category:Mexican male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مكسيكيون",
    "Category:Moldovan male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مولدوفيون",
    "Category:Norwegian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور نرويجيون",
    "Category:Austrian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور نمساويون",
    "Category:Haitian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور هايتيون",
    "Category:Dutch male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور هولنديون",
    "Category:Welsh male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ويلزيون",
    "Category:Japanese male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور يابانيون",
    "Category:Greek male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور يونانيون",
}

non_fiction_data_nat_with_time = {
    "Category:20th-century Turkish non-fiction writers": "تصنيف:كتاب غير روائيين أتراك في القرن 20",
    "Category:21st-century Turkish non-fiction writers": "تصنيف:كتاب غير روائيين أتراك في القرن 21",
    "Category:19th-century Australian non-fiction writers": "تصنيف:كتاب غير روائيين أستراليون في القرن 19",
    "Category:17th-century Irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون في القرن 17",
    "Category:18th-century Irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون في القرن 18",
    "Category:19th-century Spanish non-fiction writers": "تصنيف:كتاب غير روائيين إسبان في القرن 19",
    "Category:20th-century Spanish non-fiction writers": "تصنيف:كتاب غير روائيين إسبان في القرن 20",
    "Category:17th-century Scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون في القرن 17",
    "Category:18th-century Scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون في القرن 18",
    "Category:19th-century Scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون في القرن 19",
    "Category:20th-century Scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون في القرن 20",
    "Category:19th-century Italian non-fiction writers": "تصنيف:كتاب غير روائيين إيطاليون في القرن 19",
    "Category:19th-century Brazilian non-fiction writers": "تصنيف:كتاب غير روائيين برازيليون في القرن 19",
    "Category:20th-century Brazilian non-fiction writers": "تصنيف:كتاب غير روائيين برازيليون في القرن 20",
    "Category:21st-century Brazilian non-fiction writers": "تصنيف:كتاب غير روائيين برازيليون في القرن 21",
    "Category:20th-century Portuguese non-fiction writers": "تصنيف:كتاب غير روائيين برتغاليون في القرن 20",
    "Category:21st-century Portuguese non-fiction writers": "تصنيف:كتاب غير روائيين برتغاليون في القرن 21",
    "Category:19th-century Belgian non-fiction writers": "تصنيف:كتاب غير روائيين بلجيكيون في القرن 19",
    "Category:20th-century Bangladeshi non-fiction writers": "تصنيف:كتاب غير روائيين بنغلاديشيون في القرن 20",
    "Category:21st-century Bangladeshi non-fiction writers": "تصنيف:كتاب غير روائيين بنغلاديشيون في القرن 21",
    "Category:19th-century Puerto Rican non-fiction writers": "تصنيف:كتاب غير روائيين بورتوريكيون في القرن 19",
    "Category:20th-century Puerto Rican non-fiction writers": "تصنيف:كتاب غير روائيين بورتوريكيون في القرن 20",
    "Category:21st-century Puerto Rican non-fiction writers": "تصنيف:كتاب غير روائيين بورتوريكيون في القرن 21",
    "Category:19th-century Czech non-fiction writers": "تصنيف:كتاب غير روائيين تشيكيون في القرن 19",
    "Category:20th-century Czech non-fiction writers": "تصنيف:كتاب غير روائيين تشيكيون في القرن 20",
    "Category:21st-century Czech non-fiction writers": "تصنيف:كتاب غير روائيين تشيكيون في القرن 21",
    "Category:18th-century Danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون في القرن 18",
    "Category:19th-century Danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون في القرن 19",
    "Category:19th-century Swedish non-fiction writers": "تصنيف:كتاب غير روائيين سويديون في القرن 19",
    "Category:21st-century Swedish non-fiction writers": "تصنيف:كتاب غير روائيين سويديون في القرن 21",
    "Category:20th-century Chinese non-fiction writers": "تصنيف:كتاب غير روائيين صينيون في القرن 20",
    "Category:21st-century Chinese non-fiction writers": "تصنيف:كتاب غير روائيين صينيون في القرن 21",
    "Category:20th-century Finnish non-fiction writers": "تصنيف:كتاب غير روائيين فنلنديون في القرن 20",
    "Category:21st-century South Korean non-fiction writers": "تصنيف:كتاب غير روائيين كوريون جنوبيون في القرن 21",
    "Category:21st-century Lithuanian non-fiction writers": "تصنيف:كتاب غير روائيين ليتوانيون في القرن 21",
    "Category:20th-century Egyptian non-fiction writers": "تصنيف:كتاب غير روائيين مصريون في القرن 20",
    "Category:21st-century Egyptian non-fiction writers": "تصنيف:كتاب غير روائيين مصريون في القرن 21",
    "Category:19th-century Mexican non-fiction writers": "تصنيف:كتاب غير روائيين مكسيكيون في القرن 19",
    "Category:20th-century Mexican non-fiction writers": "تصنيف:كتاب غير روائيين مكسيكيون في القرن 20",
    "Category:21st-century Mexican non-fiction writers": "تصنيف:كتاب غير روائيين مكسيكيون في القرن 21",
    "Category:21st-century Norwegian non-fiction writers": "تصنيف:كتاب غير روائيين نرويجيون في القرن 21",
    "Category:20th-century Austrian non-fiction writers": "تصنيف:كتاب غير روائيين نمساويون في القرن 20",
    "Category:21st-century Austrian non-fiction writers": "تصنيف:كتاب غير روائيين نمساويون في القرن 21",
    "Category:17th-century Dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون في القرن 17",
    "Category:18th-century Dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون في القرن 18",
    "Category:19th-century Dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون في القرن 19",
    "Category:20th-century Welsh non-fiction writers": "تصنيف:كتاب غير روائيين ويلزيون في القرن 20",
    "Category:21st-century Welsh non-fiction writers": "تصنيف:كتاب غير روائيين ويلزيون في القرن 21",
    "Category:20th-century Japanese non-fiction writers": "تصنيف:كتاب غير روائيين يابانيون في القرن 20",
    "Category:21st-century Japanese non-fiction writers": "تصنيف:كتاب غير روائيين يابانيون في القرن 21",
    "Category:19th-century Greek non-fiction writers": "تصنيف:كتاب غير روائيين يونانيون في القرن 19",
    "Category:20th-century Greek non-fiction writers": "تصنيف:كتاب غير روائيين يونانيون في القرن 20",
    "Category:21st-century Greek non-fiction writers": "تصنيف:كتاب غير روائيين يونانيون في القرن 21",
}

to_test = [
    ("test_non_fiction_data_by", non_fiction_data_by),
    ("test_non_fiction_data_from", non_fiction_data_from),
    ("test_non_fiction_data_nats", non_fiction_data_nats),
    ("test_non_fiction_data_male", non_fiction_data_male),
    ("test_non_fiction_data_nat_with_time", non_fiction_data_nat_with_time),
]

non_fiction_data_all = {
    **non_fiction_data_by,
    **non_fiction_data_from,
    **non_fiction_data_nats,
    **non_fiction_data_male,
    **non_fiction_data_nat_with_time,
}


@pytest.mark.parametrize("category, expected", non_fiction_data_all.items(), ids=non_fiction_data_all.keys())
@pytest.mark.slow
def test_non_fiction_writers(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_non_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new.resolve_films_bots.resolve_films_labels import _get_films_key_tyty_new
from ArWikiCats.new.resolve_films_bots.resolve_films_labels_and_time import get_films_key_tyty_new_and_time

novels_films_test_data_0 = {
    "1960s Dutch-language films": "أفلام باللغة الهولندية في عقد 1960",
    "1980s films": "أفلام إنتاج عقد 1980",
    "2010s French-language films": "أفلام باللغة الفرنسية في عقد 2010",
    "2026 films": "أفلام إنتاج 2026",
    "African films by country": "أفلام إفريقية حسب البلد",
    "African-American musical films": "أفلام موسيقية أمريكية إفريقية",
    "American war films": "أفلام حربية أمريكية",
    "Animated films set in 2050s": "أفلام رسوم متحركة تقع أحداثها في عقد 2050",
    "Animated films set in Manhattan": "أفلام رسوم متحركة تقع أحداثها في مانهاتن",
    "Animated films set in Monaco": "أفلام رسوم متحركة تقع أحداثها في موناكو",
    "Animated films set in Tanzania": "أفلام رسوم متحركة تقع أحداثها في تنزانيا",
    "Arabic-language musical drama films": "أفلام موسيقية درامية باللغة العربية",
    "Arabic-language thriller films": "أفلام إثارة باللغة العربية",
    "Australian adult animated films": "أفلام رسوم متحركة للكبار أسترالية",
    "Australian fantasy films": "أفلام فانتازيا أسترالية",
    "Bangladeshi musical films": "أفلام موسيقية بنغلاديشية",
    "Belgian short films": "أفلام قصيرة بلجيكية",
    "Bengali-language comedy horror films": "أفلام كوميدية رعب باللغة البنغالية",
    "Burkinabe independent films": "أفلام مستقلة بوركينابية",
    "Canadian psychological horror films": "أفلام رعب نفسي كندية",
    "Chinese sports films": "أفلام رياضية صينية",
    "Comedy films by year": "أفلام كوميدية حسب السنة",
    "Croatian comedy horror films": "أفلام كوميدية رعب كرواتية",
    "Czech-language films by genre": "أفلام باللغة التشيكية حسب النوع الفني",
    "Danish films by studio": "أفلام دنماركية حسب استوديو الإنتاج",
    "Documentary films about David Lynch": "أفلام وثائقية عن ديفيد لينش",
    "Documentary films about film directors and producers": "أفلام وثائقية عن مخرجو أفلام ومنتجون",
    "Documentary films about immigration to Europe": "أفلام وثائقية عن الهجرة إلى أوروبا",
    "Documentary films about male prostitution": "أفلام وثائقية عن دعارة الذكور",
    "Documentary films about rape": "أفلام وثائقية عن الاغتصاب",
    "Documentary films about Werner Herzog": "أفلام وثائقية عن فرنر هرتزوغ",
    "Documentary films about women in United Kingdom": "أفلام وثائقية عن المرأة في المملكة المتحدة",
    "English-language musical films": "أفلام موسيقية باللغة الإنجليزية",
    "Films about mass shootings": "أفلام عن إطلاق نار عشوائي",
    "Films about poverty in France": "أفلام عن الفقر في فرنسا",
    "Films about racism in United Kingdom": "أفلام عن عنصرية في المملكة المتحدة",
    "Films based on American folklore": "أفلام مبنية على فلكور أمريكي",
    "Films based on Marvel Comics": "أفلام مبنية على مارفال كومكس",
    "Films based on operas by composer": "أفلام مبنية على أوبيرات حسب الملحن",
    "Films based on works by Albanian writers": "أفلام مبنية على أعمال كتاب ألبان",
    "Films based on works by Chrétien de Troyes": "أفلام مبنية على أعمال كريتيان دي تروا",
    "Films based on works by Estonian writers": "أفلام مبنية على أعمال كتاب إستونيون",
    "Films based on works by Nigerian writers": "أفلام مبنية على أعمال كتاب نيجيريون",
    "Films by Iraqi directors": "أفلام مخرجون عراقيون",
    "Films by Malaysian producers": "أفلام منتجون ماليزيون",
    "Films scored by Brazilian composers": "أفلام سجلها ملحنون برازيليون",
    "Films scored by French composers": "أفلام سجلها ملحنون فرنسيون",
    "Films set in 1670": "أفلام تقع أحداثها في 1670",
    "Films set in 1699": "أفلام تقع أحداثها في 1699",
    "Films set in 1719": "أفلام تقع أحداثها في 1719",
    "Films set in 1879": "أفلام تقع أحداثها في 1879",
    "Films set in 2026": "أفلام تقع أحداثها في 2026",
    "Films set in Bahamas": "أفلام تقع أحداثها في باهاماس",
    "Films set in castles": "أفلام تقع أحداثها في قلاع",
    "Films set in Chhattisgarh": "أفلام تقع أحداثها في تشاتيسغار",
    "Films set in Ibadan": "أفلام تقع أحداثها في إبادان",
    "Films set in Iowa": "أفلام تقع أحداثها في آيوا",
    "Films set in Suffolk": "أفلام تقع أحداثها في سوفولك",
    "Films shot in County Kildare": "أفلام مصورة في مقاطعة كيلدير",
    "Films shot in East Riding of Yorkshire": "أفلام مصورة في إيست رايدينج أوف يوركشير",
    "Films shot in Pennsylvania": "أفلام مصورة في بنسلفانيا",
    "Films shot in Sarthe": "أفلام مصورة في سارت (إقليم فرنسي)",
    "Films shot in Sindhudurg": "أفلام مصورة في سيندهودورج",
    "Films shot in South Carolina": "أفلام مصورة في كارولاينا الجنوبية",
    "Finnish films": "أفلام فنلندية",
    "Finnish-language drama films": "أفلام درامية باللغة الفنلندية",
    "French association football films": "أفلام كرة القدم الفرنسية",
    "Greenlandic documentary films": "أفلام وثائقية جرينلاندية",
    "Indonesian-language biographical films": "أفلام سير ذاتية باللغة الإندونيسية",
    "Iranian silent films": "أفلام صامتة إيرانية",
    "Italian-language adventure films": "أفلام مغامرات باللغة الإيطالية",
    "Italian-language romance films": "أفلام رومانسية باللغة الإيطالية",
    "Japanese works adapted into films": "أعمال يابانية تم تحويلها إلى أفلام",
    "Kannada-language action thriller films": "أفلام إثارة حركة باللغة الكنادية",
    "Lists of 1920 films by language": "قوائم أفلام إنتاج 1920 حسب اللغة",
    "Lists of 1976 films by language": "قوائم أفلام إنتاج 1976 حسب اللغة",
    "Lists of 2000 films": "قوائم أفلام 2000",
    "Lists of 2026 films": "قوائم أفلام 2026",
    "Lists of anime films": "قوائم أفلام أنمي",
    "Lists of films by year and language": "قوائم أفلام حسب السنة واللغة",
    "Lists of French films by decade": "قوائم أفلام فرنسية حسب العقد",
    "Luxembourgian documentary films": "أفلام وثائقية لوكسمبورغية",
    "Novellas adapted into films": "روايات قصيرة تم تحويلها إلى أفلام",
    "Pakistani drama films": "أفلام درامية باكستانية",
    "Pakistani science fiction action films": "أفلام خيال علمي وحركة باكستانية",
    "Philippine black-and-white films": "أفلام أبيض وأسود فلبينية",
    "Polish films": "أفلام بولندية",
    "Portuguese-language romance films": "أفلام رومانسية باللغة البرتغالية",
    "Romance films": "أفلام رومانسية",
    "Somalian documentary films": "أفلام وثائقية صومالية",
    "Somalian short films": "أفلام قصيرة صومالية",
    "South Korean children's films": "أفلام أطفال كورية جنوبية",
    "South Korean films by year": "أفلام كورية جنوبية حسب السنة",
    "South Korean political thriller films": "أفلام إثارة سياسية كورية جنوبية",
    "Spanish-language historical drama films": "أفلام تاريخية درامية باللغة الإسبانية",
    "Spanish-language musical comedy films": "أفلام كوميدية موسيقية باللغة الإسبانية",
    "Swedish vampire films": "أفلام مصاصي دماء سويدية",
    "Taiwanese black comedy films": "أفلام كوميدية سوداء تايوانية",
    "Urdu-language films by decade": "أفلام باللغة الأردية حسب العقد",
    "Bangladeshi musical drama films": "أفلام موسيقية درامية بنغلاديشية",
    "Croatian crime drama films": "أفلام جريمة درامية كرواتية",
    "Philippine war drama films": "أفلام حربية درامية فلبينية",
}


novels_films_test_data = {
    "1940s Canadian animated films": "أفلام رسوم متحركة كندية في عقد 1940",
    "2000s Hong Kong films": "أفلام هونغ كونغية في عقد 2000",
    "2025 South Korean films": "أفلام كورية جنوبية في 2025",
    "1510s fantasy novels": "روايات فانتازيا في عقد 1510",
    "1530s fantasy novels": "روايات فانتازيا في عقد 1530",
    "1590s fantasy novels": "روايات فانتازيا في عقد 1590",
    "1610s fantasy novels": "روايات فانتازيا في عقد 1610",
    "1620s fantasy novels": "روايات فانتازيا في عقد 1620",
    "1630s science fiction novels": "روايات خيال علمي في عقد 1630",
    "1650s science fiction novels": "روايات خيال علمي في عقد 1650",
    "1680s fantasy novels": "روايات فانتازيا في عقد 1680",
    "1720s science fiction novels": "روايات خيال علمي في عقد 1720",
    "1895 fantasy novels": "روايات فانتازيا في 1895",
    "1910s mystery films": "أفلام غموض في عقد 1910",
    "1910s pornographic films": "أفلام إباحية في عقد 1910",
    "1928 American animated short films": "أفلام رسوم متحركة قصيرة أمريكية في 1928",
    "1950 comedy films": "أفلام كوميدية في 1950",
    "1950s comedy films": "أفلام كوميدية في عقد 1950",
    "1955 science fiction novels": "روايات خيال علمي في 1955",
    "1960 anime films": "أفلام أنمي في 1960",
    "1960 comedy-drama films": "أفلام كوميدية درامية في 1960",
    "1972 independent films": "أفلام مستقلة في 1972",
    "1976 fantasy films": "أفلام فانتازيا في 1976",
    "1978 martial arts films": "أفلام فنون قتال في 1978",
    "1979 anime films": "أفلام أنمي في 1979",
    "1980 crime thriller films": "أفلام إثارة وجريمة في 1980",
    "1983 American television seasons": "مواسم تلفزيونية أمريكية في 1983",
    "1986 comedy horror films": "أفلام كوميدية رعب في 1986",
    "1986 fantasy novels": "روايات فانتازيا في 1986",
    "1989 crime films": "أفلام جريمة في 1989",
    "1990 animated short films": "أفلام رسوم متحركة قصيرة في 1990",
    "1991 crime thriller films": "أفلام إثارة وجريمة في 1991",
    "1992 action comedy films": "أفلام حركة كوميدية في 1992",
    "2000s educational films": "أفلام تعليمية في عقد 2000",
    "2002 horror films": "أفلام رعب في 2002",
    "2003 fantasy films": "أفلام فانتازيا في 2003",
    "2003 psychological thriller films": "أفلام إثارة نفسية في 2003",
    "2003 Swedish television seasons": "مواسم تلفزيونية سويدية في 2003",
    "2009 science fiction action films": "أفلام خيال علمي وحركة في 2009",
    "2010 Hungarian television seasons": "مواسم تلفزيونية مجرية في 2010",
    "2011 Slovenian television seasons": "مواسم تلفزيونية سلوفينية في 2011",
    "2012 Danish television seasons": "مواسم تلفزيونية دنماركية في 2012",
    "2013 Czech television seasons": "مواسم تلفزيونية تشيكية في 2013",
    "2014 fantasy novels": "روايات فانتازيا في 2014",
    "2014 Norwegian television seasons": "مواسم تلفزيونية نرويجية في 2014",
    "2017 Vietnamese television seasons": "مواسم تلفزيونية فيتنامية في 2017",
    "2020 romance films": "أفلام رومانسية في 2020",
    "2020s slasher films": "أفلام تقطيع في عقد 2020",
    "2021 fantasy novels": "روايات فانتازيا في 2021",
    "2026 3D films": "أفلام ثلاثية الأبعاد في 2026",
    "2026 action films": "أفلام حركة في 2026",
    "2026 action thriller films": "أفلام إثارة حركة في 2026",
    "2026 American animated films": "أفلام رسوم متحركة أمريكية في 2026",
    "2026 animated films": "أفلام رسوم متحركة في 2026",
    "2026 anime films": "أفلام أنمي في 2026",
    "2026 comedy films": "أفلام كوميدية في 2026",
    "2026 computer-animated films": "أفلام حركة حاسوبية في 2026",
    "2026 drama films": "أفلام درامية في 2026",
    "2026 fantasy films": "أفلام فانتازيا في 2026",
    "2026 horror films": "أفلام رعب في 2026",
    "2026 science fiction action films": "أفلام خيال علمي وحركة في 2026",
    "2026 science fiction films": "أفلام خيال علمي في 2026",
    "2026 thriller films": "أفلام إثارة في 2026",
}


@pytest.mark.parametrize(
    "name,data,callback", [("get_films_key_tyty_new_and_time", novels_films_test_data, get_films_key_tyty_new_and_time)]
)
@pytest.mark.dump
def test_dump_2nd(monkeypatch: pytest.MonkeyPatch, name: str, data: dict[str, str], callback) -> None:
    """
    Run a comparison test of film-label resolution with time by patching its helper and asserting the output matches expected.

    Parameters:
        monkeypatch (pytest.MonkeyPatch): pytest fixture used to replace the module's helper with a controlled implementation.
        name (str): Identifier used for dump files and test output grouping.
        data (dict[str, str]): Mapping of source film-category keys to expected translations.
        callback: The function under test that processes `data` to produce comparison results.

    No return value. The test records differences and same/not-same items, and asserts that the produced diff equals the expected result.
    """
    monkeypatch.setattr(
        "ArWikiCats.new.resolve_films_bots.resolve_films_labels_and_time.get_films_key_tyty_new",
        _get_films_key_tyty_new,
        raising=True,
    )
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
